use self::TypeOfProblem::*;
use once_cell::sync::Lazy;
use std::collections::BTreeMap;
use std::sync::Mutex;

static WINDOWS_RS_FOLDER: Lazy<Mutex<String>> = Lazy::new(|| Mutex::new(String::new()));

pub fn get_windows_rs_folder() -> String {
    WINDOWS_RS_FOLDER.lock().unwrap().clone()
}

pub fn set_windows_rs_folder(folder: String) {
    *WINDOWS_RS_FOLDER.lock().unwrap() = folder;
}

pub const IGNORE_INVALID: bool = false;

pub const DISABLED_CLASSES: &[&str] = &[
    "AddressBook", // Shows message box when os doesn't have any mail app inside
    "Imapi",       // Shows message box when os doesn't have any mail app inside
    "Shutdown",    // Shutdown computer
    //
    "ActiveDirectory",                     // dsparse.dll, dsprop.dll
    "AllJoyn",                             // msajapi.dll
    "ApplicationInstallationAndServicing", // mspatchc.dll
    "BiometricFramework",                  // winbio.dll
    "Certificates",                        // certadm.dll
    "CloudFilters",                        // cldapi.dll
    "Clustering",                          // ntlanman.dll
    "ColorSystem",                         // icm32.dll
    "Communication",                       // api-ms-win-core-comm-l1-1-1.dll, api-ms-win-core-comm-l1-1-2.dll
    "Cryptography",                        // infocardapi.dll
    "DeploymentServices",                  // wdstptc.dll
    "DeveloperLicensing",                  // wsclient.dll
    "Dhcp",                                // dhcpsapi.dll
    "DiagnosticDataQuery",                 // diagnosticdataquery.dll
    "Diagnostics",                         // windows.ui.xaml
    "EnterpriseData",                      // srpapi.dll, efswrt.dll
    "EventCollector",                      // wecapi.dll
    "ExtensibleAuthenticationProtocol",    // eappprxy.dll, eappcfg.dll
    "Fax",                                 // fxsutility.dll, winfax.dll
    "FileHistory",                         // fhsvcctl.dll
    "FileSystem",                          // clfsw32.dll, txfw32.dll, wofutil.dll
    "Gaming",                              // api-ms-win-gaming-expandedresources-l1-1-0.dll
    "Globalization",                       // bcp47mrm.dll, icu.dll
    "GroupPolicy",                         // gpedit.dll
    "HostComputeNetwork",                  // computenetwork.dll
    "HostComputeSystem",                   // computecore.dll, computestorage.dll
    "Hypervisor",                          // vmsavedstatedumpprovider.dll
    "Identity",                            // tokenbinding.dll
    "IscsiDisc",                           // iscsidsc.dll
    "Js",                                  // chakra.dll
    "Magnification",                       // magnification.dll
    "Memory",                              // api-ms-win-core-memory-l1-1-8.dll
    "MobileDeviceManagementRegistration",  // mdmlocalmanagement.dll, mdmregistration.dll
    "MsHtml",                              // imgutil.dll, msrating.dll
    "NetShell",                            // netsh.dll
    "OfflineFiles",                        // cscapi.dll
    "P2P",                                 // p2p.dll
    "ProjectedFileSystem",                 // projectedfslib.dll
    "Rpc",                                 // rpcns4.dll
    "Rras",                                // rtm.dll
    "SecurityCenter",                      // wscapi.dll
    "Sensors",                             // sensorsutilsv2.dll
    "SqlLite",                             // winsqlite3.dll
    "SubsystemForLinux",                   // api-ms-win-wsl-api-l1-1-0.dll
    "SystemInformation",                   // api-ms-win-core-sysinfo-l1-2-4.dll, api-ms-win-core-sysinfo-l1-2-3.dll
    "UserAccessLogging",                   // ualapi.dll
    "WNet",                                // ntlanman.dll
    "WinSock",                             // windows.networking
    "WindowsAndMessaging",                 // mrmsupport.dll
    "WindowsConnectionManager",            // ondemandconnroutehelper.dll
    "WindowsFirewall",                     // api-ms-win-net-isolation-l1-1-0.dll
    "WindowsNetworkVirtualization",        // wnvapi.dll
    "WindowsProgramming",                  // wldp.dll, api-ms-win-core-realtime-l1-1-2.dll, api-ms-win-core-apiquery-l2-1-0.dll
    "WindowsWebServices",                  // webauthn.dll
    "XboxController",                      // xinputuap.dll
    "Credentials",                         // keycredmgr.dll
    "DirectoryServices",                   // dssec.dll
    "Iis",                                 // rpcproxy.dll
    "LicenseProtection",                   // licenseprotection.dll
    "TabletPC",                            // inkobjcore.dll
                                           /////////////////////////
                                           // "Accessibility",
                                           // "ActiveDirectory",
                                           // "AddressBook",
                                           // "AllJoyn",
                                           // "Antimalware",
                                           // "AppLocker",
                                           // "ApplicationInstallationAndServicing",
                                           // "ApplicationVerifier",
                                           // "Appx",
                                           // "Audio",
                                           // "Authorization",
                                           // "BiometricFramework",
                                           // "Bluetooth",
                                           // "Cabinets",
                                           // "CallObj",
                                           // "Catalog",
                                           // "Ceip",
                                           // "CloudFilters",
                                           // "Clustering",
                                           // "ColorSystem",
                                           // "Com",
                                           // "Communication",
                                           // "ComponentServices",
                                           // "CompositionSwapchain",
                                           // "Compression",
                                           // "Console",
                                           // "Controls",
                                           // "CorrelationVector",
                                           // "Cryptography",
                                           // "DXCore",
                                           // "DataExchange",
                                           // "Debug",
                                           // "DeploymentServices",
                                           // "DeveloperLicensing",
                                           // "DeviceAccess",
                                           // "DeviceAndDriverInstallation",
                                           // "DeviceQuery",
                                           // "Dhcp",
                                           // "Dialogs",
                                           // "Direct2D",
                                           // "Direct3D10",
                                           // "Direct3D11",
                                           // "Direct3D112",
                                           // "Direct3D11on12",
                                           // "Direct3D12",
                                           // "Direct3D9",
                                           // "Direct3D9on12",
                                           // "DirectComposition",
                                           // "DirectDraw",
                                           // "DirectML",
                                           // "DirectShow",
                                           // "DirectSound",
                                           // "DirectWrite",
                                           // "Display",
                                           // "DistributedFileSystem",
                                           // "DistributedTransactionCoordinator",
                                           // "Dns",
                                           // "Dwm",
                                           // "DxMediaObjects",
                                           // "Dxc",
                                           // "Dxgi",
                                           // "EnterpriseData",
                                           // "Environment",
                                           // "ErrorReporting",
                                           // "Etw",
                                           // "EventCollector",
                                           // "EventLog",
                                           // "EventNotificationService",
                                           // "ExtensibleAuthenticationProtocol",
                                           // "Fax",
                                           // "FileSystem",
                                           // "Foundation",
                                           // "Fxc",
                                           // "Gaming",
                                           // "Gdi",
                                           // "Globalization",
                                           // "GroupPolicy",
                                           // "HardwareCounterProfiling",
                                           // "HiDpi",
                                           // "HostComputeNetwork",
                                           // "HostComputeSystem",
                                           // "HttpServer",
                                           // "HumanInterfaceDevice",
                                           // "Hypervisor",
                                           // "IO",
                                           // "Identity",
                                           // "Imaging",
                                           // "Imapi",
                                           // "Ime",
                                           // "IndexServer",
                                           // "Input",
                                           // "InstallableFileSystems",
                                           // "InteractionContext",
                                           // "IpHelper",
                                           // "IscsiDisc",
                                           // "Isolation",
                                           // "Jet",
                                           // "JobObjects",
                                           // "Js",
                                           // "Kernel",
                                           // "KernelStreaming",
                                           // "KeyboardAndMouse",
                                           // "Ldap",
                                           // "LibraryLoader",
                                           // "Magnification",
                                           // "Mailslots",
                                           // "Mapi",
                                           // "Marshal",
                                           // "Media",
                                           // "MediaFoundation",
                                           // "Memory",
                                           // "MobileDeviceManagementRegistration",
                                           // "MsHtml",
                                           // "Multicast",
                                           // "Multimedia",
                                           // "NetBios",
                                           // "NetManagement",
                                           // "NetShell",
                                           // "NetworkDiagnosticsFramework",
                                           // "NonVolatile",
                                           // "OfflineFiles",
                                           // "Ole",
                                           // "OpenGL",
                                           // "OperationRecorder",
                                           // "P2P",
                                           // "PasswordManagement",
                                           // "Pdf",
                                           // "Performance",
                                           // "Pipes",
                                           // "Pnp",
                                           // "Pointer",
                                           // "PortableDevices",
                                           // "Power",
                                           // "PrintTicket",
                                           // "Printer",
                                           // "Printing",
                                           // "Printing2",
                                           // "ProcessSnapshotting",
                                           // "ProcessStatus",
                                           // "ProjectedFileSystem",
                                           // "PropertiesSystem",
                                           // "QoS",
                                           // "Recovery",
                                           // "Registry",
                                           // "RemoteDesktop",
                                           // "RemoteManagement",
                                           // "RestartManager",
                                           // "Restore",
                                           // "RightsManagement",
                                           // "Rpc",
                                           // "Rras",
                                           // "Search",
                                           // "Security",
                                           // "SecurityCenter",
                                           // "Sensors",
                                           // "SerialCommunication",
                                           // "Services",
                                           // "SetupAndMigration",
                                           // "Shell",
                                           // "Shutdown",
                                           // "Sip",
                                           // "Snmp",
                                           // "SqlLite",
                                           // "StationsAndDesktops",
                                           // "StructuredStorage",
                                           // "SubsystemForLinux",
                                           // "SystemInformation",
                                           // "SystemServices",
                                           // "Tapi",
                                           // "TextServices",
                                           // "Threading",
                                           // "Time",
                                           // "ToolHelp",
                                           // "Touch",
                                           // "TpmBaseServices",
                                           // "UI",
                                           // "UI2",
                                           // "Urlmon",
                                           // "Usb",
                                           // "UserAccessLogging",
                                           // "Vhd",
                                           // "Vss",
                                           // "WNet",
                                           // "WebDav",
                                           // "WebServicesOnDevices",
                                           // "WebSocket",
                                           // "WiFi",
                                           // "WinHttp",
                                           // "WinInet",
                                           // "WinML",
                                           // "WinRT",
                                           // "WinSock",
                                           // "WinTrust",
                                           // "WindowsConnectionManager",
                                           // "WindowsFilteringPlatform",
                                           // "WindowsFirewall",
                                           // "WindowsMediaFormat",
                                           // "WindowsNetworkVirtualization",
                                           // "WindowsProgramming",
                                           // "WindowsWebServices",
                                           // "Wmi",
                                           // "XAudio2",
                                           // "XboxController",
                                           // "XmlLite",
                                           // "Xps",
];

#[derive(Eq, PartialEq, Clone, Copy, Ord, PartialOrd)]
pub enum TypeOfProblem {
    NotImplementedLinux,
    NotImplementedWindows,
    InvalidNumberOfArguments,
    ShowsDialogWindows,
    ShowsDialogLinux,
    CrashesWindows,
    CrashesLinux,
    CrashAutomatic, // Crashes are normal for this code
    Freeze,
    Other,
}
impl TypeOfProblem {
    pub fn to_string(self) -> String {
        match self {
            NotImplementedLinux => "NotImplementedLinux",
            NotImplementedWindows => "NotImplementedWindows",
            InvalidNumberOfArguments => "InvalidNumberOfArguments",
            ShowsDialogWindows => "ShowsDialogWindows",
            ShowsDialogLinux => "ShowsDialogLinux",
            CrashesWindows => "CrashesWindows",
            CrashesLinux => "CrashesLinux",
            CrashAutomatic => "CrashAutomatic",
            Freeze => "Freeze",
            Other => "Other",
        }
        .to_string()
    }
}

pub fn load_place_of_mod_rs() -> Vec<(&'static str, &'static str)> {
    vec![
        ("Accessibility", "crates/libs/sys/src/Windows/Win32/UI/Accessibility/mod.rs"),
        ("ActiveDirectory", "crates/libs/sys/src/Windows/Win32/Networking/ActiveDirectory/mod.rs"),
        ("AddressBook", "crates/libs/sys/src/Windows/Win32/System/AddressBook/mod.rs"),
        ("AllJoyn", "crates/libs/sys/src/Windows/Win32/Devices/AllJoyn/mod.rs"),
        ("Antimalware", "crates/libs/sys/src/Windows/Win32/System/Antimalware/mod.rs"),
        ("AppLocker", "crates/libs/sys/src/Windows/Win32/Security/AppLocker/mod.rs"),
        (
            "ApplicationInstallationAndServicing",
            "crates/libs/sys/src/Windows/Win32/System/ApplicationInstallationAndServicing/mod.rs",
        ),
        (
            "ApplicationVerifier",
            "crates/libs/sys/src/Windows/Win32/System/ApplicationVerifier/mod.rs",
        ),
        ("Appx", "crates/libs/sys/src/Windows/Win32/Storage/Packaging/Appx/mod.rs"),
        ("Audio", "crates/libs/sys/src/Windows/Win32/Media/Audio/mod.rs"),
        ("Authorization", "crates/libs/sys/src/Windows/Win32/Security/Authorization/mod.rs"),
        (
            "BiometricFramework",
            "crates/libs/sys/src/Windows/Win32/Devices/BiometricFramework/mod.rs",
        ),
        ("Bluetooth", "crates/libs/sys/src/Windows/Win32/Devices/Bluetooth/mod.rs"),
        ("Cabinets", "crates/libs/sys/src/Windows/Win32/Storage/Cabinets/mod.rs"),
        ("CallObj", "crates/libs/sys/src/Windows/Win32/System/Com/CallObj/mod.rs"),
        ("Catalog", "crates/libs/sys/src/Windows/Win32/Security/Cryptography/Catalog/mod.rs"),
        ("Ceip", "crates/libs/sys/src/Windows/Win32/System/Diagnostics/Ceip/mod.rs"),
        (
            "Certificates",
            "crates/libs/sys/src/Windows/Win32/Security/Cryptography/Certificates/mod.rs",
        ),
        ("CloudFilters", "crates/libs/sys/src/Windows/Win32/Storage/CloudFilters/mod.rs"),
        ("Clustering", "crates/libs/sys/src/Windows/Win32/Networking/Clustering/mod.rs"),
        ("ColorSystem", "crates/libs/sys/src/Windows/Win32/UI/ColorSystem/mod.rs"),
        ("Com", "crates/libs/sys/src/Windows/Win32/System/Com/mod.rs"),
        ("Communication", "crates/libs/sys/src/Windows/Win32/Devices/Communication/mod.rs"),
        ("ComponentServices", "crates/libs/sys/src/Windows/Win32/System/ComponentServices/mod.rs"),
        (
            "CompositionSwapchain",
            "crates/libs/sys/src/Windows/Win32/Graphics/CompositionSwapchain/mod.rs",
        ),
        ("Compression", "crates/libs/sys/src/Windows/Win32/Storage/Compression/mod.rs"),
        ("Console", "crates/libs/sys/src/Windows/Win32/System/Console/mod.rs"),
        ("Controls", "crates/libs/sys/src/Windows/Win32/UI/Controls/mod.rs"),
        ("CorrelationVector", "crates/libs/sys/src/Windows/Win32/System/CorrelationVector/mod.rs"),
        ("Credentials", "crates/libs/sys/src/Windows/Win32/Security/Credentials/mod.rs"),
        ("Cryptography", "crates/libs/sys/src/Windows/Win32/Security/Cryptography/mod.rs"),
        ("DXCore", "crates/libs/sys/src/Windows/Win32/Graphics/DXCore/mod.rs"),
        ("DataExchange", "crates/libs/sys/src/Windows/Win32/System/DataExchange/mod.rs"),
        ("Debug", "crates/libs/sys/src/Windows/Win32/System/Diagnostics/Debug/mod.rs"),
        ("DeploymentServices", "crates/libs/sys/src/Windows/Win32/System/DeploymentServices/mod.rs"),
        ("DeveloperLicensing", "crates/libs/sys/src/Windows/Win32/System/DeveloperLicensing/mod.rs"),
        ("DeviceAccess", "crates/libs/sys/src/Windows/Win32/Devices/DeviceAccess/mod.rs"),
        (
            "DeviceAndDriverInstallation",
            "crates/libs/sys/src/Windows/Win32/Devices/DeviceAndDriverInstallation/mod.rs",
        ),
        ("DeviceQuery", "crates/libs/sys/src/Windows/Win32/Devices/DeviceQuery/mod.rs"),
        ("Dhcp", "crates/libs/sys/src/Windows/Win32/NetworkManagement/Dhcp/mod.rs"),
        (
            "DiagnosticDataQuery",
            "crates/libs/sys/src/Windows/Win32/Security/DiagnosticDataQuery/mod.rs",
        ),
        ("Diagnostics", "crates/libs/sys/src/Windows/Win32/UI/Xaml/Diagnostics/mod.rs"),
        ("Dialogs", "crates/libs/sys/src/Windows/Win32/UI/Controls/Dialogs/mod.rs"),
        ("Direct2D", "crates/libs/sys/src/Windows/Win32/Graphics/Direct2D/mod.rs"),
        ("Direct3D10", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D10/mod.rs"),
        ("Direct3D11", "crates/libs/sys/src/Windows/Win32/System/WinRT/Direct3D11/mod.rs"),
        ("Direct3D112", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D11/mod.rs"),
        ("Direct3D11on12", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D11on12/mod.rs"),
        ("Direct3D12", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D12/mod.rs"),
        ("Direct3D9", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D9/mod.rs"),
        ("Direct3D9on12", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D9on12/mod.rs"),
        ("DirectComposition", "crates/libs/sys/src/Windows/Win32/Graphics/DirectComposition/mod.rs"),
        ("DirectDraw", "crates/libs/sys/src/Windows/Win32/Graphics/DirectDraw/mod.rs"),
        ("DirectML", "crates/libs/sys/src/Windows/Win32/AI/MachineLearning/DirectML/mod.rs"),
        ("DirectShow", "crates/libs/sys/src/Windows/Win32/Media/DirectShow/mod.rs"),
        ("DirectSound", "crates/libs/sys/src/Windows/Win32/Media/Audio/DirectSound/mod.rs"),
        ("DirectWrite", "crates/libs/sys/src/Windows/Win32/Graphics/DirectWrite/mod.rs"),
        ("DirectoryServices", "crates/libs/sys/src/Windows/Win32/Security/DirectoryServices/mod.rs"),
        ("Display", "crates/libs/sys/src/Windows/Win32/Devices/Display/mod.rs"),
        (
            "DistributedFileSystem",
            "crates/libs/sys/src/Windows/Win32/Storage/DistributedFileSystem/mod.rs",
        ),
        (
            "DistributedTransactionCoordinator",
            "crates/libs/sys/src/Windows/Win32/System/DistributedTransactionCoordinator/mod.rs",
        ),
        ("Dns", "crates/libs/sys/src/Windows/Win32/NetworkManagement/Dns/mod.rs"),
        ("Dwm", "crates/libs/sys/src/Windows/Win32/Graphics/Dwm/mod.rs"),
        ("DxMediaObjects", "crates/libs/sys/src/Windows/Win32/Media/DxMediaObjects/mod.rs"),
        ("Dxc", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D/Dxc/mod.rs"),
        ("Dxgi", "crates/libs/sys/src/Windows/Win32/Graphics/Dxgi/mod.rs"),
        ("EnterpriseData", "crates/libs/sys/src/Windows/Win32/Security/EnterpriseData/mod.rs"),
        ("Environment", "crates/libs/sys/src/Windows/Win32/System/Environment/mod.rs"),
        ("ErrorReporting", "crates/libs/sys/src/Windows/Win32/System/ErrorReporting/mod.rs"),
        ("Etw", "crates/libs/sys/src/Windows/Win32/System/Diagnostics/Etw/mod.rs"),
        ("EventCollector", "crates/libs/sys/src/Windows/Win32/System/EventCollector/mod.rs"),
        ("EventLog", "crates/libs/sys/src/Windows/Win32/System/EventLog/mod.rs"),
        (
            "EventNotificationService",
            "crates/libs/sys/src/Windows/Win32/System/EventNotificationService/mod.rs",
        ),
        (
            "ExtensibleAuthenticationProtocol",
            "crates/libs/sys/src/Windows/Win32/Security/ExtensibleAuthenticationProtocol/mod.rs",
        ),
        ("Fax", "crates/libs/sys/src/Windows/Win32/Devices/Fax/mod.rs"),
        ("FileHistory", "crates/libs/sys/src/Windows/Win32/Storage/FileHistory/mod.rs"),
        ("FileSystem", "crates/libs/sys/src/Windows/Win32/Storage/FileSystem/mod.rs"),
        ("Foundation", "crates/libs/sys/src/Windows/Win32/Foundation/mod.rs"),
        ("Fxc", "crates/libs/sys/src/Windows/Win32/Graphics/Direct3D/Fxc/mod.rs"),
        ("Gaming", "crates/libs/sys/src/Windows/Win32/Gaming/mod.rs"),
        ("Gdi", "crates/libs/sys/src/Windows/Win32/Graphics/Gdi/mod.rs"),
        ("Globalization", "crates/libs/sys/src/Windows/Win32/Globalization/mod.rs"),
        ("GroupPolicy", "crates/libs/sys/src/Windows/Win32/System/GroupPolicy/mod.rs"),
        (
            "HardwareCounterProfiling",
            "crates/libs/sys/src/Windows/Win32/System/Performance/HardwareCounterProfiling/mod.rs",
        ),
        ("HiDpi", "crates/libs/sys/src/Windows/Win32/UI/HiDpi/mod.rs"),
        ("HostComputeNetwork", "crates/libs/sys/src/Windows/Win32/System/HostComputeNetwork/mod.rs"),
        ("HostComputeSystem", "crates/libs/sys/src/Windows/Win32/System/HostComputeSystem/mod.rs"),
        ("HttpServer", "crates/libs/sys/src/Windows/Win32/Networking/HttpServer/mod.rs"),
        (
            "HumanInterfaceDevice",
            "crates/libs/sys/src/Windows/Win32/Devices/HumanInterfaceDevice/mod.rs",
        ),
        ("Hypervisor", "crates/libs/sys/src/Windows/Win32/System/Hypervisor/mod.rs"),
        ("IO", "crates/libs/sys/src/Windows/Win32/System/IO/mod.rs"),
        ("Identity", "crates/libs/sys/src/Windows/Win32/Security/Authentication/Identity/mod.rs"),
        ("Iis", "crates/libs/sys/src/Windows/Win32/System/Iis/mod.rs"),
        ("Imaging", "crates/libs/sys/src/Windows/Win32/Graphics/Imaging/mod.rs"),
        ("Imapi", "crates/libs/sys/src/Windows/Win32/Storage/Imapi/mod.rs"),
        ("Ime", "crates/libs/sys/src/Windows/Win32/UI/Input/Ime/mod.rs"),
        ("IndexServer", "crates/libs/sys/src/Windows/Win32/Storage/IndexServer/mod.rs"),
        ("Input", "crates/libs/sys/src/Windows/Win32/UI/Input/mod.rs"),
        (
            "InstallableFileSystems",
            "crates/libs/sys/src/Windows/Win32/Storage/InstallableFileSystems/mod.rs",
        ),
        ("InteractionContext", "crates/libs/sys/src/Windows/Win32/UI/InteractionContext/mod.rs"),
        ("IpHelper", "crates/libs/sys/src/Windows/Win32/NetworkManagement/IpHelper/mod.rs"),
        ("IscsiDisc", "crates/libs/sys/src/Windows/Win32/Storage/IscsiDisc/mod.rs"),
        ("Isolation", "crates/libs/sys/src/Windows/Win32/Security/Isolation/mod.rs"),
        ("Jet", "crates/libs/sys/src/Windows/Win32/Storage/Jet/mod.rs"),
        ("JobObjects", "crates/libs/sys/src/Windows/Win32/System/JobObjects/mod.rs"),
        ("Js", "crates/libs/sys/src/Windows/Win32/System/Js/mod.rs"),
        ("Kernel", "crates/libs/sys/src/Windows/Win32/System/Kernel/mod.rs"),
        ("KernelStreaming", "crates/libs/sys/src/Windows/Win32/Media/KernelStreaming/mod.rs"),
        ("KeyboardAndMouse", "crates/libs/sys/src/Windows/Win32/UI/Input/KeyboardAndMouse/mod.rs"),
        ("Ldap", "crates/libs/sys/src/Windows/Win32/Networking/Ldap/mod.rs"),
        ("LibraryLoader", "crates/libs/sys/src/Windows/Win32/System/LibraryLoader/mod.rs"),
        ("LicenseProtection", "crates/libs/sys/src/Windows/Win32/Security/LicenseProtection/mod.rs"),
        ("Magnification", "crates/libs/sys/src/Windows/Win32/UI/Magnification/mod.rs"),
        ("Mailslots", "crates/libs/sys/src/Windows/Win32/System/Mailslots/mod.rs"),
        ("Mapi", "crates/libs/sys/src/Windows/Win32/System/Mapi/mod.rs"),
        ("Marshal", "crates/libs/sys/src/Windows/Win32/System/Com/Marshal/mod.rs"),
        ("Media", "crates/libs/sys/src/Windows/Win32/Media/mod.rs"),
        ("MediaFoundation", "crates/libs/sys/src/Windows/Win32/Media/MediaFoundation/mod.rs"),
        ("Memory", "crates/libs/sys/src/Windows/Win32/System/Memory/mod.rs"),
        (
            "MobileDeviceManagementRegistration",
            "crates/libs/sys/src/Windows/Win32/Management/MobileDeviceManagementRegistration/mod.rs",
        ),
        ("MsHtml", "crates/libs/sys/src/Windows/Win32/Web/MsHtml/mod.rs"),
        ("Multicast", "crates/libs/sys/src/Windows/Win32/NetworkManagement/Multicast/mod.rs"),
        ("Multimedia", "crates/libs/sys/src/Windows/Win32/Media/Multimedia/mod.rs"),
        ("NetBios", "crates/libs/sys/src/Windows/Win32/NetworkManagement/NetBios/mod.rs"),
        (
            "NetManagement",
            "crates/libs/sys/src/Windows/Win32/NetworkManagement/NetManagement/mod.rs",
        ),
        ("NetShell", "crates/libs/sys/src/Windows/Win32/NetworkManagement/NetShell/mod.rs"),
        (
            "NetworkDiagnosticsFramework",
            "crates/libs/sys/src/Windows/Win32/NetworkManagement/NetworkDiagnosticsFramework/mod.rs",
        ),
        ("NonVolatile", "crates/libs/sys/src/Windows/Win32/System/Memory/NonVolatile/mod.rs"),
        ("OfflineFiles", "crates/libs/sys/src/Windows/Win32/Storage/OfflineFiles/mod.rs"),
        ("Ole", "crates/libs/sys/src/Windows/Win32/System/Ole/mod.rs"),
        ("OpenGL", "crates/libs/sys/src/Windows/Win32/Graphics/OpenGL/mod.rs"),
        ("OperationRecorder", "crates/libs/sys/src/Windows/Win32/Storage/OperationRecorder/mod.rs"),
        ("P2P", "crates/libs/sys/src/Windows/Win32/NetworkManagement/P2P/mod.rs"),
        ("PasswordManagement", "crates/libs/sys/src/Windows/Win32/System/PasswordManagement/mod.rs"),
        ("Pdf", "crates/libs/sys/src/Windows/Win32/System/WinRT/Pdf/mod.rs"),
        ("Performance", "crates/libs/sys/src/Windows/Win32/System/Performance/mod.rs"),
        ("Pipes", "crates/libs/sys/src/Windows/Win32/System/Pipes/mod.rs"),
        ("Pnp", "crates/libs/sys/src/Windows/Win32/Devices/Enumeration/Pnp/mod.rs"),
        ("Pointer", "crates/libs/sys/src/Windows/Win32/UI/Input/Pointer/mod.rs"),
        ("PortableDevices", "crates/libs/sys/src/Windows/Win32/Devices/PortableDevices/mod.rs"),
        ("Power", "crates/libs/sys/src/Windows/Win32/System/Power/mod.rs"),
        ("PrintTicket", "crates/libs/sys/src/Windows/Win32/Graphics/Printing/PrintTicket/mod.rs"),
        ("Printing", "crates/libs/sys/src/Windows/Win32/Graphics/Printing/mod.rs"),
        ("Printing2", "crates/libs/sys/src/Windows/Win32/Storage/Xps/Printing/mod.rs"),
        (
            "ProcessSnapshotting",
            "crates/libs/sys/src/Windows/Win32/System/Diagnostics/ProcessSnapshotting/mod.rs",
        ),
        ("ProcessStatus", "crates/libs/sys/src/Windows/Win32/System/ProcessStatus/mod.rs"),
        (
            "ProjectedFileSystem",
            "crates/libs/sys/src/Windows/Win32/Storage/ProjectedFileSystem/mod.rs",
        ),
        ("PropertiesSystem", "crates/libs/sys/src/Windows/Win32/UI/Shell/PropertiesSystem/mod.rs"),
        ("QoS", "crates/libs/sys/src/Windows/Win32/NetworkManagement/QoS/mod.rs"),
        ("Recovery", "crates/libs/sys/src/Windows/Win32/System/Recovery/mod.rs"),
        ("Registry", "crates/libs/sys/src/Windows/Win32/System/Registry/mod.rs"),
        ("RemoteDesktop", "crates/libs/sys/src/Windows/Win32/System/RemoteDesktop/mod.rs"),
        ("RemoteManagement", "crates/libs/sys/src/Windows/Win32/System/RemoteManagement/mod.rs"),
        ("RestartManager", "crates/libs/sys/src/Windows/Win32/System/RestartManager/mod.rs"),
        ("Restore", "crates/libs/sys/src/Windows/Win32/System/Restore/mod.rs"),
        ("RightsManagement", "crates/libs/sys/src/Windows/Win32/Data/RightsManagement/mod.rs"),
        ("Rpc", "crates/libs/sys/src/Windows/Win32/System/Rpc/mod.rs"),
        ("Rras", "crates/libs/sys/src/Windows/Win32/NetworkManagement/Rras/mod.rs"),
        ("Search", "crates/libs/sys/src/Windows/Win32/System/Search/mod.rs"),
        ("Security", "crates/libs/sys/src/Windows/Win32/Security/mod.rs"),
        ("SecurityCenter", "crates/libs/sys/src/Windows/Win32/System/SecurityCenter/mod.rs"),
        ("Sensors", "crates/libs/sys/src/Windows/Win32/Devices/Sensors/mod.rs"),
        (
            "SerialCommunication",
            "crates/libs/sys/src/Windows/Win32/Devices/SerialCommunication/mod.rs",
        ),
        ("Services", "crates/libs/sys/src/Windows/Win32/System/Services/mod.rs"),
        ("SetupAndMigration", "crates/libs/sys/src/Windows/Win32/System/SetupAndMigration/mod.rs"),
        ("Shell", "crates/libs/sys/src/Windows/Win32/UI/Shell/mod.rs"),
        ("Shutdown", "crates/libs/sys/src/Windows/Win32/System/Shutdown/mod.rs"),
        ("Sip", "crates/libs/sys/src/Windows/Win32/Security/Cryptography/Sip/mod.rs"),
        ("Snmp", "crates/libs/sys/src/Windows/Win32/NetworkManagement/Snmp/mod.rs"),
        ("SqlLite", "crates/libs/sys/src/Windows/Win32/System/SqlLite/mod.rs"),
        (
            "StationsAndDesktops",
            "crates/libs/sys/src/Windows/Win32/System/StationsAndDesktops/mod.rs",
        ),
        (
            "StructuredStorage",
            "crates/libs/sys/src/Windows/Win32/System/Com/StructuredStorage/mod.rs",
        ),
        ("SubsystemForLinux", "crates/libs/sys/src/Windows/Win32/System/SubsystemForLinux/mod.rs"),
        ("SystemInformation", "crates/libs/sys/src/Windows/Win32/System/SystemInformation/mod.rs"),
        ("SystemServices", "crates/libs/sys/src/Windows/Win32/System/SystemServices/mod.rs"),
        ("TabletPC", "crates/libs/sys/src/Windows/Win32/UI/TabletPC/mod.rs"),
        ("Tapi", "crates/libs/sys/src/Windows/Win32/Devices/Tapi/mod.rs"),
        ("TextServices", "crates/libs/sys/src/Windows/Win32/UI/TextServices/mod.rs"),
        ("Threading", "crates/libs/sys/src/Windows/Win32/System/Threading/mod.rs"),
        ("Time", "crates/libs/sys/src/Windows/Win32/System/Time/mod.rs"),
        ("ToolHelp", "crates/libs/sys/src/Windows/Win32/System/Diagnostics/ToolHelp/mod.rs"),
        ("Touch", "crates/libs/sys/src/Windows/Win32/UI/Input/Touch/mod.rs"),
        ("TpmBaseServices", "crates/libs/sys/src/Windows/Win32/System/TpmBaseServices/mod.rs"),
        ("UI", "crates/libs/sys/src/Windows/Win32/Security/Cryptography/UI/mod.rs"),
        ("UI2", "crates/libs/sys/src/Windows/Win32/Security/Authorization/UI/mod.rs"),
        ("Urlmon", "crates/libs/sys/src/Windows/Win32/System/Com/Urlmon/mod.rs"),
        ("Usb", "crates/libs/sys/src/Windows/Win32/Devices/Usb/mod.rs"),
        ("UserAccessLogging", "crates/libs/sys/src/Windows/Win32/System/UserAccessLogging/mod.rs"),
        ("Vhd", "crates/libs/sys/src/Windows/Win32/Storage/Vhd/mod.rs"),
        ("Vss", "crates/libs/sys/src/Windows/Win32/Storage/Vss/mod.rs"),
        ("WNet", "crates/libs/sys/src/Windows/Win32/NetworkManagement/WNet/mod.rs"),
        ("WebDav", "crates/libs/sys/src/Windows/Win32/NetworkManagement/WebDav/mod.rs"),
        (
            "WebServicesOnDevices",
            "crates/libs/sys/src/Windows/Win32/Devices/WebServicesOnDevices/mod.rs",
        ),
        ("WebSocket", "crates/libs/sys/src/Windows/Win32/Networking/WebSocket/mod.rs"),
        ("WiFi", "crates/libs/sys/src/Windows/Win32/NetworkManagement/WiFi/mod.rs"),
        ("WinHttp", "crates/libs/sys/src/Windows/Win32/Networking/WinHttp/mod.rs"),
        ("WinInet", "crates/libs/sys/src/Windows/Win32/Networking/WinInet/mod.rs"),
        ("WinML", "crates/libs/sys/src/Windows/Win32/AI/MachineLearning/WinML/mod.rs"),
        ("WinRT", "crates/libs/sys/src/Windows/Win32/System/WinRT/mod.rs"),
        ("WinSock", "crates/libs/sys/src/Windows/Win32/Networking/WinSock/mod.rs"),
        ("WinTrust", "crates/libs/sys/src/Windows/Win32/Security/WinTrust/mod.rs"),
        ("WindowsAndMessaging", "crates/libs/sys/src/Windows/Win32/UI/WindowsAndMessaging/mod.rs"),
        (
            "WindowsConnectionManager",
            "crates/libs/sys/src/Windows/Win32/NetworkManagement/WindowsConnectionManager/mod.rs",
        ),
        (
            "WindowsFilteringPlatform",
            "crates/libs/sys/src/Windows/Win32/NetworkManagement/WindowsFilteringPlatform/mod.rs",
        ),
        (
            "WindowsFirewall",
            "crates/libs/sys/src/Windows/Win32/NetworkManagement/WindowsFirewall/mod.rs",
        ),
        ("WindowsMediaFormat", "crates/libs/sys/src/Windows/Win32/Media/WindowsMediaFormat/mod.rs"),
        (
            "WindowsNetworkVirtualization",
            "crates/libs/sys/src/Windows/Win32/NetworkManagement/WindowsNetworkVirtualization/mod.rs",
        ),
        ("WindowsProgramming", "crates/libs/sys/src/Windows/Win32/System/WindowsProgramming/mod.rs"),
        (
            "WindowsWebServices",
            "crates/libs/sys/src/Windows/Win32/Networking/WindowsWebServices/mod.rs",
        ),
        ("Wmi", "crates/libs/sys/src/Windows/Win32/System/Wmi/mod.rs"),
        ("XAudio2", "crates/libs/sys/src/Windows/Win32/Media/Audio/XAudio2/mod.rs"),
        ("XboxController", "crates/libs/sys/src/Windows/Win32/UI/Input/XboxController/mod.rs"),
        ("XmlLite", "crates/libs/sys/src/Windows/Win32/Data/Xml/XmlLite/mod.rs"),
        ("Xps", "crates/libs/sys/src/Windows/Win32/Storage/Xps/mod.rs"),
    ]
}

pub const EXCEPTIONS: &[(&str, &str, TypeOfProblem)] = &[
    ("Accessibility", "AccNotifyTouchInteraction", NotImplementedLinux),
    ("Accessibility", "AccSetRunningUtilityState", NotImplementedLinux),
    ("Accessibility", "DockPattern_SetDockPosition", NotImplementedLinux),
    ("Accessibility", "ExpandCollapsePattern_Collapse", NotImplementedLinux),
    ("Accessibility", "ExpandCollapsePattern_Expand", NotImplementedLinux),
    ("Accessibility", "GridPattern_GetItem", NotImplementedLinux),
    ("Accessibility", "InvokePattern_Invoke", NotImplementedLinux),
    ("Accessibility", "ItemContainerPattern_FindItemByProperty", NotImplementedLinux),
    ("Accessibility", "LegacyIAccessiblePattern_DoDefaultAction", NotImplementedLinux),
    ("Accessibility", "LegacyIAccessiblePattern_Select", NotImplementedLinux),
    ("Accessibility", "LegacyIAccessiblePattern_SetValue", NotImplementedLinux),
    ("Accessibility", "MultipleViewPattern_GetViewName", NotImplementedLinux),
    ("Accessibility", "MultipleViewPattern_SetCurrentView", NotImplementedLinux),
    ("Accessibility", "RangeValuePattern_SetValue", NotImplementedLinux),
    ("Accessibility", "RegisterPointerInputTarget", NotImplementedLinux),
    ("Accessibility", "RegisterPointerInputTargetEx", NotImplementedLinux),
    ("Accessibility", "ScrollItemPattern_ScrollIntoView", NotImplementedLinux),
    ("Accessibility", "ScrollPattern_Scroll", NotImplementedLinux),
    ("Accessibility", "ScrollPattern_SetScrollPercent", NotImplementedLinux),
    ("Accessibility", "SelectionItemPattern_AddToSelection", NotImplementedLinux),
    ("Accessibility", "SelectionItemPattern_RemoveFromSelection", NotImplementedLinux),
    ("Accessibility", "SelectionItemPattern_Select", NotImplementedLinux),
    ("Accessibility", "SynchronizedInputPattern_Cancel", NotImplementedLinux),
    ("Accessibility", "SynchronizedInputPattern_StartListening", NotImplementedLinux),
    ("Accessibility", "TextPattern_RangeFromChild", NotImplementedLinux),
    ("Accessibility", "TextPattern_RangeFromPoint", NotImplementedLinux),
    ("Accessibility", "TextPattern_get_DocumentRange", NotImplementedLinux),
    ("Accessibility", "TextPattern_get_SupportedTextSelection", NotImplementedLinux),
    ("Accessibility", "TextRange_AddToSelection", NotImplementedLinux),
    ("Accessibility", "TextRange_Clone", NotImplementedLinux),
    ("Accessibility", "TextRange_Compare", NotImplementedLinux),
    ("Accessibility", "TextRange_CompareEndpoints", NotImplementedLinux),
    ("Accessibility", "TextRange_ExpandToEnclosingUnit", NotImplementedLinux),
    ("Accessibility", "TextRange_FindAttribute", NotImplementedLinux),
    ("Accessibility", "TextRange_FindText", NotImplementedLinux),
    ("Accessibility", "TextRange_GetAttributeValue", NotImplementedLinux),
    ("Accessibility", "TextRange_GetEnclosingElement", NotImplementedLinux),
    ("Accessibility", "TextRange_GetText", NotImplementedLinux),
    ("Accessibility", "TextRange_Move", NotImplementedLinux),
    ("Accessibility", "TextRange_MoveEndpointByRange", NotImplementedLinux),
    ("Accessibility", "TextRange_MoveEndpointByUnit", NotImplementedLinux),
    ("Accessibility", "TextRange_RemoveFromSelection", NotImplementedLinux),
    ("Accessibility", "TextRange_ScrollIntoView", NotImplementedLinux),
    ("Accessibility", "TextRange_Select", NotImplementedLinux),
    ("Accessibility", "TogglePattern_Toggle", NotImplementedLinux),
    ("Accessibility", "TransformPattern_Move", NotImplementedLinux),
    ("Accessibility", "TransformPattern_Resize", NotImplementedLinux),
    ("Accessibility", "TransformPattern_Rotate", NotImplementedLinux),
    ("Accessibility", "UiaAddEvent", NotImplementedLinux),
    ("Accessibility", "UiaDisconnectAllProviders", NotImplementedLinux),
    ("Accessibility", "UiaEventAddWindow", NotImplementedLinux),
    ("Accessibility", "UiaEventRemoveWindow", NotImplementedLinux),
    ("Accessibility", "UiaGetErrorDescription", NotImplementedLinux),
    ("Accessibility", "UiaGetPatternProvider", NotImplementedLinux),
    ("Accessibility", "UiaGetPropertyValue", NotImplementedLinux),
    ("Accessibility", "UiaGetRootNode", NotImplementedLinux),
    ("Accessibility", "UiaHPatternObjectFromVariant", NotImplementedLinux),
    ("Accessibility", "UiaHTextRangeFromVariant", NotImplementedLinux),
    ("Accessibility", "UiaHUiaNodeFromVariant", NotImplementedLinux),
    ("Accessibility", "UiaHasServerSideProvider", NotImplementedLinux),
    ("Accessibility", "UiaNodeFromHandle", NotImplementedLinux),
    ("Accessibility", "UiaNodeRelease", NotImplementedLinux),
    ("Accessibility", "UiaPatternRelease", NotImplementedLinux),
    ("Accessibility", "UiaRemoveEvent", NotImplementedLinux),
    ("Accessibility", "UiaSetFocus", NotImplementedLinux),
    ("Accessibility", "UiaTextRangeRelease", NotImplementedLinux),
    ("Accessibility", "UnregisterPointerInputTarget", NotImplementedLinux),
    ("Accessibility", "UnregisterPointerInputTargetEx", NotImplementedLinux),
    ("Accessibility", "ValuePattern_SetValue", NotImplementedLinux),
    ("Accessibility", "VirtualizedItemPattern_Realize", NotImplementedLinux),
    ("Accessibility", "WindowPattern_Close", NotImplementedLinux),
    ("Accessibility", "WindowPattern_SetWindowVisualState", NotImplementedLinux),
    ("Accessibility", "WindowPattern_WaitForInputIdle", NotImplementedLinux),
    ("Antimalware", "AmsiCloseSession", CrashesWindows),
    ("Antimalware", "AmsiInitialize", InvalidNumberOfArguments),
    ("Antimalware", "AmsiOpenSession", InvalidNumberOfArguments),
    ("Antimalware", "AmsiScanString", InvalidNumberOfArguments),
    ("Antimalware", "InstallELAMCertificateInfo", NotImplementedLinux),
    ("AppLocker", "SaferiIsExecutableFileType", NotImplementedLinux),
    ("Appx", "AppPolicyGetClrCompat", NotImplementedLinux),
    ("Appx", "AppPolicyGetCreateFileAccess", NotImplementedLinux),
    ("Appx", "AppPolicyGetLifecycleManagement", NotImplementedLinux),
    ("Appx", "AppPolicyGetProcessTerminationMethod", NotImplementedLinux),
    ("Appx", "AppPolicyGetShowDeveloperDiagnostic", NotImplementedLinux),
    ("Appx", "AppPolicyGetThreadInitializationType", NotImplementedLinux),
    ("Appx", "AppPolicyGetWindowingModel", NotImplementedLinux),
    ("Appx", "CheckIsMSIXPackage", InvalidNumberOfArguments),
    ("Appx", "DeactivatePackageVirtualizationContext", NotImplementedWindows),
    ("Appx", "DeletePackageDependency", NotImplementedWindows),
    ("Appx", "FindPackagesByPackageFamily", NotImplementedLinux),
    ("Appx", "FormatApplicationUserModelId", NotImplementedLinux),
    ("Appx", "GetApplicationUserModelId", NotImplementedLinux),
    ("Appx", "GetApplicationUserModelIdFromToken", NotImplementedLinux),
    ("Appx", "GetCurrentApplicationUserModelId", NotImplementedLinux),
    ("Appx", "GetCurrentPackageInfo", NotImplementedLinux),
    ("Appx", "GetCurrentPackageInfo2", NotImplementedLinux),
    ("Appx", "GetCurrentPackagePath2", NotImplementedLinux),
    ("Appx", "GetCurrentPackageVirtualizationContext", NotImplementedWindows),
    ("Appx", "GetPackageFamilyNameFromToken", NotImplementedLinux),
    ("Appx", "GetPackageFullNameFromToken", NotImplementedLinux),
    ("Appx", "GetPackageId", NotImplementedLinux),
    ("Appx", "GetPackagePathByFullName", NotImplementedLinux),
    ("Appx", "GetPackagePathByFullName2", NotImplementedLinux),
    ("Appx", "GetPackagesByPackageFamily", NotImplementedLinux),
    ("Appx", "GetResolvedPackageFullNameForPackageDependency", InvalidNumberOfArguments),
    ("Appx", "GetStagedPackageOrigin", NotImplementedLinux),
    ("Appx", "GetStagedPackagePathByFullName", NotImplementedLinux),
    ("Appx", "GetStagedPackagePathByFullName2", NotImplementedLinux),
    ("Appx", "PackageFamilyNameFromFullName", NotImplementedLinux),
    ("Appx", "PackageNameAndPublisherIdFromFamilyName", NotImplementedLinux),
    ("Appx", "ParseApplicationUserModelId", NotImplementedLinux),
    ("Appx", "TryCreatePackageDependency", InvalidNumberOfArguments),
    ("Appx", "VerifyApplicationUserModelId", NotImplementedLinux),
    ("Appx", "VerifyPackageFamilyName", NotImplementedLinux),
    ("Appx", "VerifyPackageFullName", NotImplementedLinux),
    ("Appx", "VerifyPackageRelativeApplicationId", NotImplementedLinux),
    ("Authorization", "AuthzEnumerateSecurityEventSources", NotImplementedLinux),
    ("Authorization", "AuthzFreeAuditEvent", NotImplementedLinux),
    ("Authorization", "AuthzFreeCentralAccessPolicyCache", NotImplementedLinux),
    ("Authorization", "AuthzFreeHandle", NotImplementedLinux),
    ("Authorization", "AuthzInitializeCompoundContext", NotImplementedLinux),
    ("Authorization", "AuthzInitializeObjectAccessAuditEvent", NotImplementedLinux),
    ("Authorization", "AuthzInitializeObjectAccessAuditEvent2", NotImplementedLinux),
    ("Authorization", "AuthzRegisterSecurityEventSource", NotImplementedLinux),
    ("Authorization", "AuthzReportSecurityEvent", NotImplementedLinux),
    ("Authorization", "AuthzUninstallSecurityEventSource", NotImplementedLinux),
    ("Authorization", "AuthzUnregisterSecurityEventSource", NotImplementedLinux),
    ("BiometricFramework", "WinBioEnrollCapture", CrashesWindows),
    ("BiometricFramework", "WinBioLocateSensor", CrashesWindows),
    ("Bluetooth", "BluetoothAuthenticateDevice", NotImplementedLinux),
    ("Bluetooth", "BluetoothAuthenticateMultipleDevices", NotImplementedLinux),
    ("Bluetooth", "BluetoothDisplayDeviceProperties", ShowsDialogWindows),
    ("Bluetooth", "BluetoothEnableDiscovery", NotImplementedLinux),
    ("Bluetooth", "BluetoothEnableIncomingConnections", NotImplementedLinux),
    ("Bluetooth", "BluetoothFindDeviceClose", CrashesWindows),
    ("Bluetooth", "BluetoothFindNextDevice", NotImplementedLinux),
    ("Bluetooth", "BluetoothFindNextRadio", CrashesWindows),
    ("Bluetooth", "BluetoothFindRadioClose", CrashesWindows),
    ("Bluetooth", "BluetoothGetDeviceInfo", NotImplementedLinux),
    ("Bluetooth", "BluetoothGetRadioInfo", NotImplementedLinux),
    ("Bluetooth", "BluetoothIsConnectable", NotImplementedLinux),
    ("Bluetooth", "BluetoothIsDiscoverable", NotImplementedLinux),
    ("Bluetooth", "BluetoothIsVersionAvailable", NotImplementedLinux),
    ("Bluetooth", "BluetoothSelectDevices", NotImplementedLinux),
    ("Bluetooth", "BluetoothSelectDevicesFree", NotImplementedLinux),
    ("Bluetooth", "BluetoothUnregisterAuthentication", CrashesWindows),
    ("Cabinets", "FDICreate", CrashesWindows),
    ("Catalog", "CryptCATAdminAddCatalog", CrashesWindows),
    ("Catalog", "CryptCATAdminCalcHashFromFileHandle2", CrashesWindows),
    ("Catalog", "CryptCATAdminPauseServiceForBackup", NotImplementedLinux),
    ("Catalog", "CryptCATAdminReleaseCatalogContext", CrashesWindows),
    ("Catalog", "CryptCATAdminReleaseContext", CrashesWindows),
    ("Catalog", "CryptCATAdminRemoveCatalog", CrashesLinux),
    ("Catalog", "CryptCATAdminResolveCatalogPath", CrashesWindows),
    ("Catalog", "CryptCATAllocSortedMemberInfo", NotImplementedLinux),
    ("Catalog", "CryptCATCatalogInfoFromContext", CrashesWindows),
    ("Catalog", "CryptCATStoreFromHandle", NotImplementedLinux),
    ("Ceip", "CeipIsOptedIn", NotImplementedLinux),
    ("Ceip", "CryptCATStoreFromHandle", NotImplementedLinux),
    ("CloudFilters", "CfGetTransferKey", CrashesWindows),
    ("Com", "CLSIDFromProgID", InvalidNumberOfArguments),
    ("Com", "CLSIDFromProgIDEx", InvalidNumberOfArguments),
    ("Com", "CLSIDFromString", InvalidNumberOfArguments),
    ("Com", "CoCancelCall", NotImplementedLinux),
    ("Com", "CoCreateGuid", InvalidNumberOfArguments),
    ("Com", "CoDecrementMTAUsage", CrashesWindows),
    ("Com", "CoDisconnectContext", NotImplementedLinux),
    ("Com", "CoFileTimeNow", InvalidNumberOfArguments),
    ("Com", "CoGetCallerTID", InvalidNumberOfArguments),
    ("Com", "CoGetContextToken", InvalidNumberOfArguments),
    ("Com", "CoGetCurrentLogicalThreadId", InvalidNumberOfArguments),
    ("Com", "CoIncrementMTAUsage", InvalidNumberOfArguments),
    ("Com", "CoInvalidateRemoteMachineBindings", NotImplementedLinux),
    ("Com", "CoRegisterDeviceCatalog", InvalidNumberOfArguments),
    ("Com", "CoRevokeDeviceCatalog", NotImplementedWindows),
    ("Com", "CoTestCancel", NotImplementedLinux),
    ("Com", "GetClassFile", InvalidNumberOfArguments),
    ("Com", "IIDFromString", InvalidNumberOfArguments),
    ("ComponentServices", "GetManagedExtensions", NotImplementedLinux),
    ("ComponentServices", "RecycleSurrogate", NotImplementedLinux),
    ("Compression", "CloseDecompressor", CrashesWindows),
    ("Compression", "ResetDecompressor", CrashesWindows),
    ("Console", "CreatePseudoConsole", InvalidNumberOfArguments),
    ("Console", "FreeConsole", CrashesWindows),
    ("Console", "GetConsoleAliasExesA", NotImplementedLinux),
    ("Console", "GetConsoleAliasExesW", NotImplementedLinux),
    ("Console", "GetConsoleAliasesA", NotImplementedLinux),
    ("Console", "GetConsoleAliasesW", NotImplementedLinux),
    ("Console", "GetConsoleOriginalTitleA", NotImplementedLinux),
    ("Console", "GetConsoleOriginalTitleW", NotImplementedLinux),
    ("Console", "GetConsoleTitleA", CrashesLinux),
    ("Console", "GetThemeBitmap", InvalidNumberOfArguments),
    ("Console", "GetThemeBool", InvalidNumberOfArguments),
    ("Console", "GetThemeFont", InvalidNumberOfArguments),
    ("Console", "GetThemeIntList", InvalidNumberOfArguments),
    ("Console", "GetThemeMetric", InvalidNumberOfArguments),
    ("Console", "GetThemePropertyOrigin", InvalidNumberOfArguments),
    ("Console", "GetThemeSysFont", InvalidNumberOfArguments),
    ("Console", "GetThemeTextMetrics", InvalidNumberOfArguments),
    ("Console", "LoadIconWithScaleDown", InvalidNumberOfArguments),
    ("Console", "SetConsoleNumberOfCommandsA", NotImplementedLinux),
    ("Console", "SetConsoleNumberOfCommandsW", NotImplementedLinux),
    ("Console", "SetConsoleTitleW", CrashesLinux),
    ("Console", "TaskDialog", InvalidNumberOfArguments),
    ("Controls", "BeginPanningFeedback", NotImplementedLinux),
    ("Controls", "CreatePseudoConsole", InvalidNumberOfArguments),
    ("Controls", "DPA_Clone", CrashesWindows),
    ("Controls", "DPA_GetSize", NotImplementedWindows),
    ("Controls", "DPA_Sort", CrashesWindows),
    ("Controls", "DSA_Clone", NotImplementedWindows),
    ("Controls", "DSA_DeleteAllItems", CrashesWindows),
    ("Controls", "DSA_DeleteItem", CrashesWindows),
    ("Controls", "DSA_GetItemPtr", CrashesWindows),
    ("Controls", "DSA_GetSize", NotImplementedWindows),
    ("Controls", "DSA_Sort", NotImplementedWindows),
    ("Controls", "DestroyPropertySheetPage", CrashesWindows),
    ("Controls", "DlgDirSelectComboBoxExA", CrashesWindows),
    ("Controls", "DlgDirSelectExA", CrashesWindows),
    ("Controls", "EndBufferedPaint", CrashesLinux),
    ("Controls", "EndPanningFeedback", NotImplementedLinux),
    ("Controls", "GetBufferedPaintDC", CrashesLinux),
    ("Controls", "GetBufferedPaintTargetDC", CrashesLinux),
    ("Controls", "GetBufferedPaintTargetRect", InvalidNumberOfArguments),
    ("Controls", "GetThemeBitmap", InvalidNumberOfArguments),
    ("Controls", "GetThemeBool", InvalidNumberOfArguments),
    ("Controls", "GetThemeColor", InvalidNumberOfArguments),
    ("Controls", "GetThemeEnumValue", InvalidNumberOfArguments),
    ("Controls", "GetThemeFilename", CrashesLinux),
    ("Controls", "GetThemeFont", InvalidNumberOfArguments),
    ("Controls", "GetThemeInt", InvalidNumberOfArguments),
    ("Controls", "GetThemeIntList", InvalidNumberOfArguments),
    ("Controls", "GetThemeMetric", InvalidNumberOfArguments),
    ("Controls", "GetThemePosition", InvalidNumberOfArguments),
    ("Controls", "GetThemePropertyOrigin", InvalidNumberOfArguments),
    ("Controls", "GetThemeRect", InvalidNumberOfArguments),
    ("Controls", "GetThemeString", CrashesLinux),
    ("Controls", "GetThemeSysFont", InvalidNumberOfArguments),
    ("Controls", "GetThemeSysInt", InvalidNumberOfArguments),
    ("Controls", "GetThemeTextMetrics", InvalidNumberOfArguments),
    ("Controls", "GetThemeTransitionDuration", InvalidNumberOfArguments),
    ("Controls", "IsThemeBackgroundPartiallyTransparent", CrashesLinux),
    ("Controls", "IsThemePartDefined", CrashesLinux),
    ("Controls", "LoadIconWithScaleDown", InvalidNumberOfArguments),
    ("Controls", "Str_SetPtrW", NotImplementedLinux),
    ("Controls", "TaskDialog", InvalidNumberOfArguments),
    ("Controls", "UpdatePanningFeedback", NotImplementedLinux),
    ("Controls", "PropertySheetA", ShowsDialogLinux),
    ("Controls", "PropertySheetW", ShowsDialogLinux),
    ("Credentials", "CredGetSessionTypes", CrashesWindows),
    ("Credentials", "CredRenameA", NotImplementedLinux),
    ("Credentials", "CredRenameW", NotImplementedLinux),
    ("Credentials", "CredUIConfirmCredentialsA", NotImplementedLinux),
    ("Credentials", "CredUIParseUserNameA", CrashesWindows),
    ("Credentials", "CredUnprotectA", NotImplementedLinux),
    ("Credentials", "CredUnprotectW", NotImplementedLinux),
    ("Credentials", "SCardAudit", NotImplementedLinux),
    ("Credentials", "SCardBeginTransaction", NotImplementedLinux),
    ("Credentials", "SCardConnectA", NotImplementedLinux),
    ("Credentials", "SCardConnectW", NotImplementedLinux),
    ("Credentials", "SCardDisconnect", NotImplementedLinux),
    ("Credentials", "SCardDlgExtendedError", NotImplementedLinux),
    ("Credentials", "SCardEndTransaction", NotImplementedLinux),
    ("Credentials", "SCardForgetCardTypeA", NotImplementedLinux),
    ("Credentials", "SCardForgetCardTypeW", NotImplementedLinux),
    ("Credentials", "SCardForgetReaderA", NotImplementedLinux),
    ("Credentials", "SCardForgetReaderGroupA", NotImplementedLinux),
    ("Credentials", "SCardForgetReaderGroupW", NotImplementedLinux),
    ("Credentials", "SCardForgetReaderW", NotImplementedLinux),
    ("Credentials", "SCardGetAttrib", NotImplementedLinux),
    ("Credentials", "SCardGetCardTypeProviderNameA", NotImplementedLinux),
    ("Credentials", "SCardGetCardTypeProviderNameW", NotImplementedLinux),
    ("Credentials", "SCardGetDeviceTypeIdA", NotImplementedLinux),
    ("Credentials", "SCardGetDeviceTypeIdW", NotImplementedLinux),
    ("Credentials", "SCardGetProviderIdA", NotImplementedLinux),
    ("Credentials", "SCardGetProviderIdW", NotImplementedLinux),
    ("Credentials", "SCardGetReaderDeviceInstanceIdA", NotImplementedLinux),
    ("Credentials", "SCardGetReaderDeviceInstanceIdW", NotImplementedLinux),
    ("Credentials", "SCardGetReaderIconA", NotImplementedLinux),
    ("Credentials", "SCardGetReaderIconW", NotImplementedLinux),
    ("Credentials", "SCardGetTransmitCount", NotImplementedLinux),
    ("Credentials", "SCardIntroduceReaderA", NotImplementedLinux),
    ("Credentials", "SCardIntroduceReaderGroupA", NotImplementedLinux),
    ("Credentials", "SCardIntroduceReaderGroupW", NotImplementedLinux),
    ("Credentials", "SCardIntroduceReaderW", NotImplementedLinux),
    ("Credentials", "SCardListInterfacesA", NotImplementedLinux),
    ("Credentials", "SCardListInterfacesW", NotImplementedLinux),
    ("Credentials", "SCardListReaderGroupsA", NotImplementedLinux),
    ("Credentials", "SCardListReaderGroupsW", NotImplementedLinux),
    ("Credentials", "SCardListReadersWithDeviceInstanceIdA", NotImplementedLinux),
    ("Credentials", "SCardListReadersWithDeviceInstanceIdW", NotImplementedLinux),
    ("Credentials", "SCardReconnect", NotImplementedLinux),
    ("Credentials", "SCardRemoveReaderFromGroupA", NotImplementedLinux),
    ("Credentials", "SCardRemoveReaderFromGroupW", NotImplementedLinux),
    ("Credentials", "SCardSetCardTypeProviderNameA", NotImplementedLinux),
    ("Credentials", "SCardSetCardTypeProviderNameW", NotImplementedLinux),
    ("Credentials", "SCardState", NotImplementedLinux),
    ("DataExchange", "GetAtomNameA", CrashesWindows),
    ("DataExchange", "GetAtomNameW", CrashesWindows),
    ("DataExchange", "GlobalAddAtomExA", NotImplementedLinux),
    ("DataExchange", "GlobalAddAtomExW", NotImplementedLinux),
    ("DataExchange", "GlobalGetAtomNameA", CrashesWindows),
    ("DataExchange", "GlobalGetAtomNameW", CrashesWindows),
    ("Debug", "Beep", Freeze),
    ("Debug", "DebugBreak", CrashAutomatic),
    ("Debug", "FatalAppExitA", CrashAutomatic),
    ("Debug", "FatalAppExitW", CrashAutomatic),
    ("Debug", "FatalExit", CrashAutomatic),
    ("Debug", "FindDebugInfoFile", CrashesLinux),
    ("Debug", "FindFileInSearchPath", NotImplementedLinux),
    ("Debug", "GetSymLoadError", NotImplementedLinux),
    ("Debug", "MakeSureDirectoryPathExists", CrashesLinux),
    ("Debug", "RangeMapCreate", NotImplementedLinux),
    ("Debug", "ReBaseImage64", NotImplementedLinux),
    ("Debug", "RemoveInvalidModuleList", NotImplementedLinux),
    ("Debug", "SearchTreeForFileW", CrashesLinux),
    ("Debug", "SetSymLoadError", NotImplementedLinux),
    ("Debug", "SymAddrIncludeInlineTrace", NotImplementedLinux),
    ("Debug", "SymCompareInlineTrace", NotImplementedLinux),
    ("Debug", "SymDeleteSymbol", NotImplementedLinux),
    ("Debug", "SymDeleteSymbolW", NotImplementedLinux),
    ("Debug", "SymFunctionTableAccess", NotImplementedWindows),
    ("Debug", "SymGetFileLineOffsets64", NotImplementedLinux),
    ("Debug", "SymGetModuleBase", NotImplementedWindows),
    ("Debug", "SymGetSearchPath", CrashesWindows),
    ("Debug", "SymGetSourceFile", NotImplementedLinux),
    ("Debug", "SymGetSourceFileChecksum", NotImplementedLinux),
    ("Debug", "SymGetSourceFileChecksumW", NotImplementedLinux),
    ("Debug", "SymGetSourceFileW", NotImplementedLinux),
    ("Debug", "SymLoadModule", NotImplementedWindows),
    ("Debug", "SymMatchFileName", CrashesLinux),
    ("Debug", "SymMatchFileNameW", CrashesWindows),
    ("Debug", "SymQueryInlineTrace", NotImplementedLinux),
    ("Debug", "SymSrvDeltaName", NotImplementedLinux),
    ("Debug", "SymSrvDeltaNameW", NotImplementedLinux),
    ("Debug", "SymSrvGetFileIndexString", NotImplementedLinux),
    ("Debug", "SymSrvGetFileIndexStringW", NotImplementedLinux),
    ("Debug", "SymSrvGetFileIndexes", NotImplementedLinux),
    ("Debug", "SymSrvGetFileIndexesW", NotImplementedLinux),
    ("Debug", "SymSrvGetSupplement", NotImplementedLinux),
    ("Debug", "SymSrvGetSupplementW", NotImplementedLinux),
    ("Debug", "SymSrvIsStore", NotImplementedLinux),
    ("Debug", "SymSrvIsStoreW", NotImplementedLinux),
    ("Debug", "SymSrvStoreSupplement", NotImplementedLinux),
    ("Debug", "SymSrvStoreSupplementW", NotImplementedLinux),
    ("Debug", "SymUnloadModule", NotImplementedWindows),
    ("Debug", "TerminateProcessOnMemoryExhaustion", NotImplementedWindows),
    ("DeploymentServices", "WdsCliFindFirstImage", CrashesWindows),
    ("DeploymentServices", "WdsCliGetDriverQueryXml", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetEnumerationFlags", CrashesWindows),
    ("DeploymentServices", "WdsCliGetImageDescription", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetImageGroup", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetImageHalName", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetImageHandleFromFindHandle", CrashesWindows),
    ("DeploymentServices", "WdsCliGetImageHandleFromTransferHandle", CrashesWindows),
    ("DeploymentServices", "WdsCliGetImageIndex", CrashesWindows),
    ("DeploymentServices", "WdsCliGetImageLanguage", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetImageName", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetImageNamespace", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetImagePath", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetImageSize", CrashesWindows),
    ("DeploymentServices", "WdsCliGetImageVersion", InvalidNumberOfArguments),
    ("DeploymentServices", "WdsCliGetTransferSize", CrashesWindows),
    ("DeviceAndDriverInstallation", "CM_Add_IDA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Add_IDW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Add_ID_ExA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Add_ID_ExW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Add_Range", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Create_Range_List", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Delete_DevNode_Key", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Delete_DevNode_Key_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Delete_Device_Interface_KeyA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Delete_Device_Interface_KeyW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Delete_Device_Interface_Key_ExA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Delete_Device_Interface_Key_ExW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Delete_Range", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Disable_DevNode", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Disable_DevNode_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Dup_Range_List", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Enable_DevNode", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Enable_DevNode_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Enumerate_Classes_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Enumerate_EnumeratorsA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Enumerate_EnumeratorsW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Enumerate_Enumerators_ExA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Enumerate_Enumerators_ExW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Find_Range", CrashesLinux),
    ("DeviceAndDriverInstallation", "CM_First_Range", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Log_Conf", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Log_Conf_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Log_Conf_Handle", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Range_List", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Res_Des", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Res_Des_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Res_Des_Handle", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Free_Resource_Conflict_Handle", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Depth", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Depth_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Device_ID_ListA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Device_ID_ListW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Device_ID_List_ExA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Device_ID_List_ExW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Device_ID_List_Size_ExA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Device_ID_List_Size_ExW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Device_ID_Size_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_First_Log_Conf", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_First_Log_Conf_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Global_State", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Global_State_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Log_Conf_Priority", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Log_Conf_Priority_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Next_Log_Conf", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Next_Log_Conf_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Next_Res_Des", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Next_Res_Des_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Parent_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Res_Des_Data_Size", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Res_Des_Data_Size_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Resource_Conflict_Count", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Get_Version_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Intersect_Range_List", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Invert_Range_List", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Is_Dock_Station_Present", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Is_Dock_Station_Present_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Is_Version_Available", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Is_Version_Available_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Merge_Range_List", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Move_DevNode", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Move_DevNode_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Next_Range", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Open_DevNode_Key_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Open_Device_Interface_KeyA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Open_Device_Interface_KeyW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Open_Device_Interface_Key_ExA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Open_Device_Interface_Key_ExW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Query_Arbitrator_Free_Size", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Query_Arbitrator_Free_Size_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Query_Remove_SubTree", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Query_Remove_SubTree_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Register_Device_Driver", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Register_Device_Driver_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Remove_SubTree", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Remove_SubTree_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Request_Eject_PC", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Request_Eject_PC_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Run_Detection", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Run_Detection_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Set_DevNode_Problem", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Set_DevNode_Problem_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Set_HW_Prof", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Set_HW_Prof_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Setup_DevNode", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Setup_DevNode_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Test_Range_Available", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Uninstall_DevNode", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Uninstall_DevNode_Ex", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Unregister_Device_InterfaceA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Unregister_Device_InterfaceW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Unregister_Device_Interface_ExA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "CM_Unregister_Device_Interface_ExW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "DiShowUpdateDriver", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "DiUninstallDriverA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "DiUninstallDriverW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "InstallHinfSectionW", ShowsDialogWindows),
    ("DeviceAndDriverInstallation", "SetupBackupErrorA", ShowsDialogWindows),
    ("DeviceAndDriverInstallation", "SetupBackupErrorW", ShowsDialogWindows),
    ("DeviceAndDriverInstallation", "SetupCancelTemporarySourceList", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupDeleteErrorA", ShowsDialogWindows),
    ("DeviceAndDriverInstallation", "SetupDeleteErrorW", ShowsDialogWindows),
    ("DeviceAndDriverInstallation", "SetupDiBuildClassInfoList", CrashesWindows),
    ("DeviceAndDriverInstallation", "SetupDiClassGuidsFromNameW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupDiGetHwProfileFriendlyNameA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupDiGetHwProfileFriendlyNameW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupDiGetHwProfileList", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupGetInfPublishedNameA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupGetInfPublishedNameW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupGetThreadLogToken", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupOpenInfFileW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupOpenInfFileW", CrashesLinux),
    ("DeviceAndDriverInstallation", "SetupRemoveFromSourceListA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupRemoveFromSourceListW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupRenameErrorA", ShowsDialogWindows),
    ("DeviceAndDriverInstallation", "SetupRenameErrorW", ShowsDialogWindows),
    ("DeviceAndDriverInstallation", "SetupSetPlatformPathOverrideA", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupSetPlatformPathOverrideW", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupSetThreadLogToken", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupWriteTextLog", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "SetupWriteTextLogError", NotImplementedLinux),
    ("DeviceAndDriverInstallation", "UpdateDriverForPlugAndPlayDevicesW", NotImplementedLinux),
    ("DiagnosticDataQuery", "DdqGetDiagnosticRecordPayload", InvalidNumberOfArguments),
    ("DiagnosticDataQuery", "DdqGetDiagnosticReportStoreReportCount", InvalidNumberOfArguments),
    ("Direct3D10", "D3D10StateBlockMaskDisableAll", InvalidNumberOfArguments),
    ("Direct3D10", "D3D10StateBlockMaskEnableAll", InvalidNumberOfArguments),
    ("DirectComposition", "DCompositionBoostCompositorClock", NotImplementedWindows),
    ("DirectComposition", "DCompositionGetFrameId", InvalidNumberOfArguments),
    ("DirectComposition", "DCompositionGetStatistics", NotImplementedWindows),
    ("DirectShow", "AMGetErrorTextA", CrashesWindows),
    ("Display", "EngAcquireSemaphore", CrashesWindows),
    ("Display", "EngCheckAbort", NotImplementedLinux),
    ("Display", "EngComputeGlyphSet", NotImplementedLinux),
    ("Display", "EngCreateClip", NotImplementedLinux),
    ("Display", "EngCreatePalette", NotImplementedLinux),
    ("Display", "EngCreateSemaphore", NotImplementedLinux),
    ("Display", "EngFindResource", NotImplementedLinux),
    ("Display", "EngFreeModule", NotImplementedLinux),
    ("Display", "EngGetCurrentCodePage", NotImplementedLinux),
    ("Display", "EngLoadModule", NotImplementedLinux),
    ("Display", "EngMultiByteToUnicodeN", CrashesWindows),
    ("Display", "EngMultiByteToWideChar", NotImplementedLinux),
    ("Display", "EngReleaseSemaphore", CrashesWindows),
    ("Display", "EngUnicodeToMultiByteN", CrashesWindows),
    ("Display", "EngUnlockSurface", NotImplementedLinux),
    ("Display", "EngWideCharToMultiByte", NotImplementedLinux),
    ("Display", "HT_Get8BPPFormatPalette", CrashesWindows),
    ("Display", "HT_Get8BPPMaskPalette", CrashesWindows),
    ("DistributedFileSystem", "NetDfsAdd", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsAddFtRoot", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsAddRootTarget", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsAddStdRoot", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsMove", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsRemove", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsRemoveFtRoot", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsRemoveFtRootForced", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsRemoveRootTarget", NotImplementedLinux),
    ("DistributedFileSystem", "NetDfsRemoveStdRoot", NotImplementedLinux),
    ("Dns", "DnsFreeProxyName", NotImplementedLinux),
    ("Dwm", "DwmGetCompositionTimingInfo", InvalidNumberOfArguments),
    ("Dwm", "DwmGetGraphicsStreamClient", InvalidNumberOfArguments),
    ("Dwm", "DwmGetGraphicsStreamTransformHint", InvalidNumberOfArguments),
    ("Dwm", "DwmGetUnmetTabRequirements", InvalidNumberOfArguments),
    ("Dwm", "DwmIsCompositionEnabled", InvalidNumberOfArguments),
    ("Dwm", "DwmModifyPreviousDxFrameDuration", NotImplementedLinux),
    ("Dwm", "DwmQueryThumbnailSourceSize", InvalidNumberOfArguments),
    ("Dwm", "DwmRegisterThumbnail", InvalidNumberOfArguments),
    ("Dwm", "DwmSetDxFrameDuration", NotImplementedLinux),
    ("Dwm", "DwmTetherContact", NotImplementedLinux),
    ("DxMediaObjects", "MoDeleteMediaType", CrashesWindows),
    ("Dxgi", "DXGIDeclareAdapterRemovalSupport", NotImplementedLinux),
    ("Environment", "EnclaveGetEnclaveInformation", InvalidNumberOfArguments),
    ("Environment", "ExpandEnvironmentStringsA", CrashesWindows),
    ("Environment", "ExpandEnvironmentStringsForUserW", CrashesWindows),
    ("Environment", "ExpandEnvironmentStringsW", CrashesWindows),
    ("Environment", "GetCurrentDirectoryA", CrashesWindows),
    ("Environment", "GetCurrentDirectoryW", Freeze),
    ("Environment", "IsEnclaveTypeSupported", NotImplementedLinux),
    ("Environment", "NeedCurrentDirectoryForExePathA", CrashesWindows),
    ("Environment", "NeedCurrentDirectoryForExePathW", CrashesWindows),
    ("Environment", "SetEnvironmentStringsW", CrashesWindows),
    ("Environment", "SetEnvironmentVariableW", CrashesWindows),
    ("ErrorReporting", "AddERExcludedApplicationW", CrashesLinux),
    ("ErrorReporting", "WerFreeString", NotImplementedLinux),
    ("ErrorReporting", "WerGetFlags", InvalidNumberOfArguments),
    ("ErrorReporting", "WerRegisterAdditionalProcess", NotImplementedLinux),
    ("ErrorReporting", "WerRegisterAppLocalDump", CrashesWindows),
    ("ErrorReporting", "WerRegisterCustomMetadata", NotImplementedLinux),
    ("ErrorReporting", "WerReportHang", NotImplementedLinux),
    ("ErrorReporting", "WerReportSubmit", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreGetFirstReportKey", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreGetNextReportKey", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreGetReportCount", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreGetSizeOnDisk", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreOpen", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStorePurge", NotImplementedLinux),
    ("ErrorReporting", "WerStoreQueryReportMetadataV1", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreQueryReportMetadataV2", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreQueryReportMetadataV3", InvalidNumberOfArguments),
    ("ErrorReporting", "WerStoreUploadReport", InvalidNumberOfArguments),
    ("ErrorReporting", "WerUnregisterAdditionalProcess", NotImplementedLinux),
    ("ErrorReporting", "WerUnregisterAppLocalDump", NotImplementedLinux),
    ("ErrorReporting", "WerUnregisterCustomMetadata", NotImplementedLinux),
    ("Etw", "CveEventWrite", NotImplementedLinux),
    ("Etw", "TdhEnumerateProviders", CrashesWindows),
    ("Etw", "TdhEnumerateProvidersForDecodingSource", NotImplementedWindows),
    ("Etw", "TdhUnloadManifest", NotImplementedLinux),
    ("EventLog", "EvtArchiveExportedLog", NotImplementedLinux),
    ("EventLog", "EvtCancel", NotImplementedLinux),
    ("EventLog", "EvtClearLog", NotImplementedLinux),
    ("EventLog", "EvtCreateBookmark", NotImplementedLinux),
    ("EventLog", "EvtGetExtendedStatus", NotImplementedLinux),
    ("EventLog", "EvtGetObjectArraySize", NotImplementedLinux),
    ("EventLog", "EvtNextEventMetadata", NotImplementedLinux),
    ("EventLog", "EvtNextPublisherId", NotImplementedLinux),
    ("EventLog", "EvtOpenEventMetadataEnum", NotImplementedLinux),
    ("EventLog", "EvtOpenPublisherEnum", NotImplementedLinux),
    ("EventLog", "EvtOpenPublisherMetadata", NotImplementedLinux),
    ("EventLog", "EvtSeek", NotImplementedLinux),
    ("EventLog", "EvtUpdateBookmark", NotImplementedLinux),
    ("FileHistory", "FhServiceOpenPipe", InvalidNumberOfArguments),
    ("FileSystem", "WofGetDriverVersion", CrashesWindows),
    ("FileSystem", "WofWimAddEntry", CrashesWindows),
    ("Gaming", "GetExpandedResourceExclusiveCpuCount", InvalidNumberOfArguments),
    ("Gdi", "AddFontResourceW", CrashesWindows),
    ("Gdi", "AlphaBlend", NotImplementedWindows),
    ("Gdi", "DrawStateA", CrashesWindows),
    ("Gdi", "DrawStateW", CrashesWindows),
    ("Gdi", "EnumDisplaySettingsExA", CrashesWindows),
    ("Gdi", "GetEnhMetaFileA", CrashesWindows),
    ("Gdi", "GetEnhMetaFileW", CrashesWindows),
    ("Gdi", "GetMetaFileA", CrashesWindows),
    ("Gdi", "GetMetaFileW", CrashesWindows),
    ("Gdi", "GetTextExtentExPointA", CrashesLinux),
    ("Gdi", "GetTextExtentPoint32W", CrashesWindows),
    ("Gdi", "GetTextExtentPointW", CrashesWindows),
    ("Gdi", "MapWindowPoints", CrashesWindows),
    ("Gdi", "TTEnableEmbeddingForFacename", CrashesLinux),
    ("Gdi", "TransparentBlt", NotImplementedWindows),
    ("Globalization", "GetDistanceOfClosestLanguageInList", InvalidNumberOfArguments),
    ("HardwareCounterProfiling", "DisableThreadProfiling", NotImplementedLinux),
    ("HardwareCounterProfiling", "EnableThreadProfiling", NotImplementedLinux),
    ("HardwareCounterProfiling", "QueryThreadProfiling", NotImplementedLinux),
    ("HiDpi", "GetDialogControlDpiChangeBehavior", NotImplementedLinux),
    ("HiDpi", "GetDialogDpiChangeBehavior", NotImplementedLinux),
    ("HiDpi", "GetDpiAwarenessContextForProcess", NotImplementedLinux),
    ("HiDpi", "GetProcessDpiAwareness", InvalidNumberOfArguments),
    ("HiDpi", "GetSystemDpiForProcess", NotImplementedLinux),
    ("HiDpi", "GetThreadDpiHostingBehavior", NotImplementedLinux),
    ("HiDpi", "GetWindowDpiHostingBehavior", NotImplementedLinux),
    ("HostComputeSystem", "HcsGetLayerVhdMountPath", InvalidNumberOfArguments),
    (
        "HostComputeSystem",
        "HcsGetProcessorCompatibilityFromSavedState",
        InvalidNumberOfArguments,
    ),
    ("HostComputeSystem", "HcsGetServiceProperties", InvalidNumberOfArguments),
    ("HostComputeSystem", "HcsModifyServiceSettings", InvalidNumberOfArguments),
    ("HttpServer", "HttpAddUrlToUrlGroup", NotImplementedLinux),
    ("HttpServer", "HttpFindUrlGroupId", NotImplementedLinux),
    ("HttpServer", "HttpRemoveUrlFromUrlGroup", CrashesLinux),
    ("HttpServer", "HttpShutdownRequestQueue", NotImplementedLinux),
    ("HumanInterfaceDevice", "HidD_FreePreparsedData", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetButtonArray", NotImplementedWindows),
    ("HumanInterfaceDevice", "HidP_GetButtonCaps", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetCaps", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetData", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetExtendedAttributes", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetLinkCollectionNodes", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetScaledUsageValue", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetSpecificButtonCaps", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetSpecificValueCaps", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetUsageValue", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetUsageValueArray", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetUsages", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetUsagesEx", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_GetValueCaps", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_InitializeReportForID", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_MaxDataListLength", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_MaxUsageListLength", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_SetData", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_SetScaledUsageValue", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_SetUsageValue", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_SetUsageValueArray", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_SetUsages", CrashesWindows),
    ("HumanInterfaceDevice", "HidP_UnsetUsages", CrashesWindows),
    ("Identity", "SLGetWindowsInformationDWORD", CrashesWindows),
    ("Imaging", "WICMapShortNameToGuid", InvalidNumberOfArguments),
    ("Ime", "ImmInstallIMEA", CrashesWindows),
    ("Ime", "ImmInstallIMEW", NotImplementedLinux),
    ("Ime", "ImmSetHotKey", NotImplementedLinux),
    ("InstallableFileSystems", "FilterAttach", NotImplementedWindows),
    ("InstallableFileSystems", "FilterAttachAtAltitude", NotImplementedWindows),
    ("InstallableFileSystems", "FilterClose", NotImplementedWindows),
    ("InstallableFileSystems", "FilterCreate", InvalidNumberOfArguments),
    ("InstallableFileSystems", "FilterDetach", NotImplementedWindows),
    ("InstallableFileSystems", "FilterFindClose", NotImplementedWindows),
    ("InstallableFileSystems", "FilterGetDosName", NotImplementedWindows),
    ("InstallableFileSystems", "FilterGetMessage", NotImplementedWindows),
    ("InstallableFileSystems", "FilterInstanceClose", NotImplementedWindows),
    ("InstallableFileSystems", "FilterInstanceCreate", InvalidNumberOfArguments),
    ("InstallableFileSystems", "FilterInstanceFindClose", NotImplementedWindows),
    ("InstallableFileSystems", "FilterLoad", NotImplementedWindows),
    ("InstallableFileSystems", "FilterUnload", NotImplementedWindows),
    ("InstallableFileSystems", "FilterVolumeFindClose", NotImplementedWindows),
    ("InstallableFileSystems", "FilterVolumeInstanceFindClose", NotImplementedWindows),
    ("InteractionContext", "AddPointerInteractionContext", NotImplementedLinux),
    ("InteractionContext", "CreateInteractionContext", InvalidNumberOfArguments),
    ("InteractionContext", "GetCrossSlideParameterInteractionContext", InvalidNumberOfArguments),
    ("InteractionContext", "GetHoldParameterInteractionContext", InvalidNumberOfArguments),
    ("InteractionContext", "GetMouseWheelParameterInteractionContext", InvalidNumberOfArguments),
    ("InteractionContext", "GetTapParameterInteractionContext", InvalidNumberOfArguments),
    (
        "InteractionContext",
        "GetTranslationParameterInteractionContext",
        InvalidNumberOfArguments,
    ),
    ("InteractionContext", "ProcessBufferedPacketsInteractionContext", NotImplementedLinux),
    ("InteractionContext", "RemovePointerInteractionContext", NotImplementedLinux),
    ("InteractionContext", "ResetInteractionContext", NotImplementedLinux),
    ("InteractionContext", "SetPivotInteractionContext", NotImplementedLinux),
    ("InteractionContext", "StopInteractionContext", NotImplementedLinux),
    ("IpHelper", "ConvertCompartmentIdToGuid", NotImplementedLinux),
    ("IpHelper", "ConvertIpv4MaskToLength", NotImplementedLinux),
    ("IpHelper", "CreatePersistentTcpPortReservation", NotImplementedLinux),
    ("IpHelper", "CreatePersistentUdpPortReservation", NotImplementedLinux),
    ("IpHelper", "DeletePersistentTcpPortReservation", NotImplementedLinux),
    ("IpHelper", "DeletePersistentUdpPortReservation", NotImplementedLinux),
    ("IpHelper", "FlushIpNetTable2", NotImplementedLinux),
    ("IpHelper", "FlushIpPathTable", NotImplementedLinux),
    ("IpHelper", "GetAdapterIndex", CrashesLinux),
    ("IpHelper", "GetAdapterOrderMap", NotImplementedLinux),
    ("IpHelper", "GetAdaptersInfo", CrashesWindows),
    ("IpHelper", "GetCurrentThreadCompartmentId", NotImplementedLinux),
    ("IpHelper", "GetCurrentThreadCompartmentScope", NotImplementedLinux),
    ("IpHelper", "GetDefaultCompartmentId", NotImplementedLinux),
    ("IpHelper", "GetIfTable", CrashesWindows),
    ("IpHelper", "GetIpErrorString", CrashesWindows),
    ("IpHelper", "GetIpForwardTable", CrashesWindows),
    ("IpHelper", "GetIpNetTable", CrashesWindows),
    ("IpHelper", "GetJobCompartmentId", NotImplementedLinux),
    ("IpHelper", "GetNetworkParams", CrashesWindows),
    ("IpHelper", "GetSessionCompartmentId", NotImplementedLinux),
    ("IpHelper", "GetTcpTable", CrashesWindows),
    ("IpHelper", "GetTcpTable2", CrashesWindows),
    ("IpHelper", "GetTeredoPort", NotImplementedLinux),
    ("IpHelper", "LookupPersistentTcpPortReservation", NotImplementedLinux),
    ("IpHelper", "LookupPersistentUdpPortReservation", NotImplementedLinux),
    ("IpHelper", "PfDeleteLog", NotImplementedLinux),
    ("IpHelper", "PfMakeLog", NotImplementedLinux),
    ("IpHelper", "PfSetLogBuffer", NotImplementedLinux),
    ("IpHelper", "SetCurrentThreadCompartmentId", NotImplementedLinux),
    ("IpHelper", "SetCurrentThreadCompartmentScope", NotImplementedLinux),
    ("IpHelper", "SetJobCompartmentId", NotImplementedLinux),
    ("IpHelper", "SetSessionCompartmentId", NotImplementedLinux),
    ("IpHelper", "UnregisterInterfaceTimestampConfigChange", NotImplementedWindows),
    ("Isolation", "DeleteAppContainerProfile", NotImplementedLinux),
    ("Isolation", "DeriveAppContainerSidFromAppContainerName", InvalidNumberOfArguments),
    (
        "Isolation",
        "DeriveRestrictedAppContainerSidFromAppContainerSidAndRestrictedName",
        InvalidNumberOfArguments,
    ),
    ("Isolation", "GetAppContainerFolderPath", InvalidNumberOfArguments),
    ("Isolation", "GetAppContainerNamedObjectPath", NotImplementedLinux),
    ("Isolation", "GetAppContainerRegistryLocation", InvalidNumberOfArguments),
    ("Isolation", "IsProcessInIsolatedContainer", InvalidNumberOfArguments),
    ("Isolation", "IsProcessInIsolatedWindowsEnvironment", InvalidNumberOfArguments),
    ("Jet", "JetBeginExternalBackup", NotImplementedLinux),
    ("Jet", "JetBeginExternalBackupInstance", NotImplementedLinux),
    ("Jet", "JetBeginTransaction", NotImplementedLinux),
    ("Jet", "JetBeginTransaction2", NotImplementedLinux),
    ("Jet", "JetBeginTransaction3", NotImplementedLinux),
    ("Jet", "JetCloseDatabase", NotImplementedLinux),
    ("Jet", "JetCloseTable", NotImplementedLinux),
    ("Jet", "JetCommitTransaction", NotImplementedLinux),
    ("Jet", "JetComputeStats", NotImplementedLinux),
    ("Jet", "JetConfigureProcessForCrashDump", NotImplementedLinux),
    ("Jet", "JetDelete", NotImplementedLinux),
    ("Jet", "JetDupCursor", NotImplementedLinux),
    ("Jet", "JetDupSession", NotImplementedLinux),
    ("Jet", "JetEndExternalBackup", NotImplementedLinux),
    ("Jet", "JetEndExternalBackupInstance", NotImplementedLinux),
    ("Jet", "JetEndExternalBackupInstance2", NotImplementedLinux),
    ("Jet", "JetEndSession", NotImplementedLinux),
    ("Jet", "JetFreeBuffer", NotImplementedLinux),
    ("Jet", "JetGetAttachInfoA", NotImplementedLinux),
    ("Jet", "JetGetAttachInfoInstanceA", NotImplementedLinux),
    ("Jet", "JetGetAttachInfoInstanceW", NotImplementedLinux),
    ("Jet", "JetGetAttachInfoW", NotImplementedLinux),
    ("Jet", "JetGetCurrentIndexA", NotImplementedLinux),
    ("Jet", "JetGetCurrentIndexW", NotImplementedLinux),
    ("Jet", "JetGetLock", NotImplementedLinux),
    ("Jet", "JetGetLogInfoA", NotImplementedLinux),
    ("Jet", "JetGetLogInfoInstanceA", NotImplementedLinux),
    ("Jet", "JetGetLogInfoInstanceW", NotImplementedLinux),
    ("Jet", "JetGetLogInfoW", NotImplementedLinux),
    ("Jet", "JetGetTruncateLogInfoInstanceA", NotImplementedLinux),
    ("Jet", "JetGetTruncateLogInfoInstanceW", NotImplementedLinux),
    ("Jet", "JetGetVersion", NotImplementedLinux),
    ("Jet", "JetIdle", NotImplementedLinux),
    ("Jet", "JetIndexRecordCount", NotImplementedLinux),
    ("Jet", "JetInit", NotImplementedLinux),
    ("Jet", "JetInit2", NotImplementedLinux),
    ("Jet", "JetMove", NotImplementedLinux),
    ("Jet", "JetPrepareUpdate", NotImplementedLinux),
    ("Jet", "JetResetSessionContext", NotImplementedLinux),
    ("Jet", "JetResetTableSequential", NotImplementedLinux),
    ("Jet", "JetResizeDatabase", NotImplementedLinux),
    ("Jet", "JetRollback", NotImplementedLinux),
    ("Jet", "JetSeek", NotImplementedLinux),
    ("Jet", "JetSetIndexRange", NotImplementedLinux),
    ("Jet", "JetSetTableSequential", NotImplementedLinux),
    ("Jet", "JetStopBackup", NotImplementedLinux),
    ("Jet", "JetStopBackupInstance", NotImplementedLinux),
    ("Jet", "JetStopService", NotImplementedLinux),
    ("Jet", "JetStopServiceInstance", NotImplementedLinux),
    ("Jet", "JetStopServiceInstance2", NotImplementedLinux),
    ("Jet", "JetTerm", NotImplementedLinux),
    ("Jet", "JetTerm2", NotImplementedLinux),
    ("Jet", "JetTruncateLog", NotImplementedLinux),
    ("Jet", "JetTruncateLogInstance", NotImplementedLinux),
    ("Kernel", "RtlInitializeSListHead", CrashesWindows),
    ("Kernel", "RtlInterlockedFlushSList", CrashesWindows),
    ("Kernel", "RtlInterlockedPushEntrySList", CrashesWindows),
    ("Kernel", "RtlInterlockedPushListSListEx", CrashesWindows),
    ("KeyboardAndMouse", "GetKeyNameTextA", CrashesWindows),
    ("KeyboardAndMouse", "GetKeyboardLayoutNameA", CrashesWindows),
    ("KeyboardAndMouse", "LoadKeyboardLayoutW", CrashesWindows),
    ("Ldap", "McastApiCleanup", NotImplementedLinux),
    ("Ldap", "McastApiStartup", NotImplementedLinux),
    ("Ldap", "ber_bvfree", CrashesWindows),
    ("Ldap", "cldap_open", CrashesWindows),
    ("Ldap", "cldap_openA", CrashesWindows),
    ("Ldap", "cldap_openW", CrashesWindows),
    ("Ldap", "ldap_compare_s", CrashesLinux),
    ("Ldap", "ldap_compare_sA", CrashesLinux),
    ("Ldap", "ldap_compare_sW", CrashesLinux),
    ("Ldap", "ldap_control_free", CrashesWindows),
    ("Ldap", "ldap_control_freeA", CrashesWindows),
    ("Ldap", "ldap_control_freeW", CrashesWindows),
    ("Ldap", "ldap_delete", CrashesLinux),
    ("Ldap", "ldap_deleteA", CrashesLinux),
    ("Ldap", "ldap_deleteW", CrashesLinux),
    ("Ldap", "ldap_delete_s", CrashesLinux),
    ("Ldap", "ldap_delete_sA", CrashesLinux),
    ("Ldap", "ldap_delete_sW", CrashesLinux),
    ("Ldap", "ldap_err2string", CrashesWindows),
    ("Ldap", "ldap_err2stringA", CrashesWindows),
    ("Ldap", "ldap_err2stringW", CrashesWindows),
    ("Ldap", "ldap_init", CrashesWindows),
    ("Ldap", "ldap_initA", CrashesWindows),
    ("Ldap", "ldap_initW", CrashesWindows),
    ("Ldap", "ldap_msgfree", CrashesWindows),
    ("Ldap", "ldap_open", CrashesWindows),
    ("Ldap", "ldap_openA", CrashesWindows),
    ("Ldap", "ldap_openW", CrashesWindows),
    ("Ldap", "ldap_set_dbg_flags", NotImplementedLinux),
    ("Ldap", "ldap_simple_bind", CrashesLinux),
    ("Ldap", "ldap_simple_bindA", CrashesLinux),
    ("Ldap", "ldap_simple_bindW", CrashesLinux),
    ("Ldap", "ldap_simple_bind_s", CrashesLinux),
    ("Ldap", "ldap_simple_bind_sA", CrashesLinux),
    ("Ldap", "ldap_simple_bind_sW", CrashesLinux),
    ("Ldap", "ldap_sslinit", CrashesWindows),
    ("Ldap", "ldap_sslinitA", CrashesWindows),
    ("Ldap", "ldap_sslinitW", CrashesWindows),
    ("Ldap", "ldap_unbind", CrashesLinux),
    ("Ldap", "ldap_unbind_s", CrashesLinux),
    ("LibraryLoader", "AddDllDirectory", CrashesWindows),
    ("LibraryLoader", "BeginUpdateResourceW", CrashesLinux),
    ("LibraryLoader", "FreeLibraryAndExitThread", CrashAutomatic),
    ("LibraryLoader", "GetDllDirectoryA", CrashesWindows),
    ("LibraryLoader", "GetDllDirectoryW", CrashesWindows),
    ("LibraryLoader", "GetModuleFileNameA", CrashesWindows),
    ("LibraryLoader", "GetModuleFileNameW", Freeze),
    ("LicenseProtection", "RegisterLicenseKeyWithExpiration", InvalidNumberOfArguments),
    ("MediaFoundation", "MFAllocateSerialWorkQueue", InvalidNumberOfArguments),
    ("MediaFoundation", "MFAllocateWorkQueue", InvalidNumberOfArguments),
    ("MediaFoundation", "MFAllocateWorkQueueEx", InvalidNumberOfArguments),
    ("MediaFoundation", "MFCreateSequencerSegmentOffset", InvalidNumberOfArguments),
    ("MediaFoundation", "MFFrameRateToAverageTimePerFrame", InvalidNumberOfArguments),
    ("MediaFoundation", "MFGetPlaneSize", InvalidNumberOfArguments),
    ("MediaFoundation", "MFGetStrideForBitmapInfoHeader", InvalidNumberOfArguments),
    ("MediaFoundation", "MFGetSupportedMimeTypes", InvalidNumberOfArguments),
    ("MediaFoundation", "MFGetSupportedSchemes", InvalidNumberOfArguments),
    ("MediaFoundation", "MFGetTimerPeriodicity", InvalidNumberOfArguments),
    ("MediaFoundation", "MFGetWorkQueueMMCSSPriority", InvalidNumberOfArguments),
    ("MediaFoundation", "MFGetWorkQueueMMCSSTaskId", InvalidNumberOfArguments),
    (
        "MobileDeviceManagementRegistration",
        "ApplyLocalManagementSyncML",
        InvalidNumberOfArguments,
    ),
    (
        "MobileDeviceManagementRegistration",
        "IsManagementRegistrationAllowed",
        InvalidNumberOfArguments,
    ),
    ("MobileDeviceManagementRegistration", "IsMdmUxWithoutAadAllowed", InvalidNumberOfArguments),
    (
        "MobileDeviceManagementRegistration",
        "RegisterDeviceWithLocalManagement",
        InvalidNumberOfArguments,
    ),
    ("MsHtml", "RatingObtainQuery", InvalidNumberOfArguments),
    ("MsHtml", "RatingObtainQueryW", InvalidNumberOfArguments),
    ("Multicast", "McastApiCleanup", NotImplementedLinux),
    ("Multicast", "McastApiStartup", NotImplementedLinux),
    ("Multimedia", "AVIBuildFilterA", CrashesWindows),
    ("Multimedia", "AVIBuildFilterW", CrashesWindows),
    ("Multimedia", "DrawDibClose", CrashesWindows),
    ("Multimedia", "DrawDibEnd", CrashesWindows),
    ("Multimedia", "DrawDibGetBuffer", CrashesWindows),
    ("Multimedia", "DrawDibGetPalette", CrashesWindows),
    ("Multimedia", "DrawDibSetPalette", CrashesWindows),
    ("Multimedia", "DrawDibStart", CrashesWindows),
    ("Multimedia", "DrawDibStop", CrashesWindows),
    ("Multimedia", "DriverCallback", CrashesWindows),
    ("Multimedia", "ICInstall", CrashesWindows),
    ("Multimedia", "MCIWndCreateA", ShowsDialogWindows),
    ("Multimedia", "MCIWndCreateW", ShowsDialogWindows),
    ("Multimedia", "OpenDriver", CrashesLinux),
    ("Multimedia", "mciGetDeviceIDA", CrashesWindows),
    ("Multimedia", "mciGetDeviceIDFromElementIDA", CrashesWindows),
    ("Multimedia", "mciSendStringA", CrashesWindows),
    ("Multimedia", "mciSendStringW", CrashesWindows),
    ("Multimedia", "mmTaskBlock", Freeze),
    ("Multimedia", "mmTaskCreate", CrashesWindows),
    ("Multimedia", "mmioOpenA", CrashesWindows),
    ("Multimedia", "mmioStringToFOURCCA", CrashesLinux),
    ("Multimedia", "mmioStringToFOURCCW", CrashesWindows),
    ("Multimedia", "sndOpenSound", NotImplementedLinux),
    ("Multimedia", "sndOpenSound", NotImplementedLinux),
    ("NetManagement", "GetNetScheduleAccountInformation", NotImplementedLinux),
    ("NetManagement", "GetNetScheduleAccountInformation", NotImplementedLinux),
    ("NetManagement", "NetAccessDel", NotImplementedLinux),
    ("NetManagement", "NetAccessDel", NotImplementedLinux),
    ("NetManagement", "NetAccessGetUserPerms", NotImplementedLinux),
    ("NetManagement", "NetAccessGetUserPerms", NotImplementedLinux),
    ("NetManagement", "NetAddAlternateComputerName", NotImplementedLinux),
    ("NetManagement", "NetAddAlternateComputerName", NotImplementedLinux),
    ("NetManagement", "NetAddServiceAccount", NotImplementedLinux),
    ("NetManagement", "NetAddServiceAccount", NotImplementedLinux),
    ("NetManagement", "NetAuditClear", NotImplementedLinux),
    ("NetManagement", "NetAuditWrite", NotImplementedLinux),
    ("NetManagement", "NetConfigSet", NotImplementedLinux),
    ("NetManagement", "NetGetDisplayInformationIndex", NotImplementedLinux),
    ("NetManagement", "NetGroupDel", NotImplementedLinux),
    ("NetManagement", "NetGroupDelUser", NotImplementedLinux),
    ("NetManagement", "NetIsServiceAccount", NotImplementedLinux),
    ("NetManagement", "NetMessageNameAdd", NotImplementedLinux),
    ("NetManagement", "NetMessageNameDel", NotImplementedLinux),
    ("NetManagement", "NetRemoveAlternateComputerName", NotImplementedLinux),
    ("NetManagement", "NetRemoveServiceAccount", NotImplementedLinux),
    ("NetManagement", "NetRenameMachineInDomain", NotImplementedLinux),
    ("NetManagement", "NetReplExportDirDel", NotImplementedLinux),
    ("NetManagement", "NetReplExportDirLock", NotImplementedLinux),
    ("NetManagement", "NetReplExportDirUnlock", NotImplementedLinux),
    ("NetManagement", "NetReplImportDirDel", NotImplementedLinux),
    ("NetManagement", "NetReplImportDirLock", NotImplementedLinux),
    ("NetManagement", "NetReplImportDirUnlock", NotImplementedLinux),
    ("NetManagement", "NetScheduleJobAdd", CrashesWindows),
    ("NetManagement", "NetScheduleJobDel", NotImplementedLinux),
    ("NetManagement", "NetServerComputerNameAdd", NotImplementedLinux),
    ("NetManagement", "NetServerComputerNameDel", NotImplementedLinux),
    ("NetManagement", "NetSetPrimaryComputerName", NotImplementedLinux),
    ("NetManagement", "NetUnjoinDomain", NotImplementedLinux),
    ("NetManagement", "RouterAssert", CrashesWindows),
    ("NetManagement", "RouterGetErrorStringA", NotImplementedLinux),
    ("NetManagement", "RouterGetErrorStringW", NotImplementedLinux),
    ("NetManagement", "RouterLogDeregisterA", NotImplementedLinux),
    ("NetManagement", "RouterLogDeregisterW", NotImplementedLinux),
    ("NetManagement", "RouterLogEventExA", NotImplementedLinux),
    ("NetManagement", "RouterLogEventExW", NotImplementedLinux),
    ("NetManagement", "RouterLogEventValistExA", NotImplementedLinux),
    ("NetManagement", "RouterLogEventValistExW", NotImplementedLinux),
    ("NetManagement", "RouterLogRegisterA", NotImplementedLinux),
    ("NetManagement", "RouterLogRegisterW", NotImplementedLinux),
    ("NetManagement", "SetNetScheduleAccountInformation", NotImplementedLinux),
    ("NetManagement", "TraceDeregisterA", NotImplementedLinux),
    ("NetManagement", "TraceDeregisterExA", NotImplementedLinux),
    ("NetManagement", "TraceDeregisterExW", NotImplementedLinux),
    ("NetManagement", "TraceDeregisterW", NotImplementedLinux),
    ("NetManagement", "TraceDumpExA", NotImplementedLinux),
    ("NetManagement", "TraceDumpExW", NotImplementedLinux),
    ("NetManagement", "TraceGetConsoleA", NotImplementedLinux),
    ("NetManagement", "TraceGetConsoleW", NotImplementedLinux),
    ("NetManagement", "TracePrintfA", NotImplementedLinux),
    ("NetManagement", "TracePrintfExA", NotImplementedLinux),
    ("NetManagement", "TracePrintfExW", NotImplementedLinux),
    ("NetManagement", "TracePrintfW", NotImplementedLinux),
    ("NetManagement", "TracePutsExA", NotImplementedLinux),
    ("NetManagement", "TracePutsExW", NotImplementedLinux),
    ("NetManagement", "TraceVprintfExA", NotImplementedLinux),
    ("NetManagement", "TraceVprintfExW", NotImplementedLinux),
    ("Ole", "OaEnablePerUserTLibRegistration", NotImplementedLinux),
    ("Ole", "OleDestroyMenuDescriptor", CrashesWindows),
    ("Ole", "VarBoolFromCy", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromDate", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromI1", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromI2", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromI4", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromI8", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromR4", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromR8", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromStr", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromUI1", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromUI2", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromUI4", InvalidNumberOfArguments),
    ("Ole", "VarBoolFromUI8", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromBool", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromCy", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromDate", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromI1", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromI2", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromI4", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromI8", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromR4", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromR8", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromUI1", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromUI2", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromUI4", InvalidNumberOfArguments),
    ("Ole", "VarBstrFromUI8", InvalidNumberOfArguments),
    ("Ole", "VarCyAbs", InvalidNumberOfArguments),
    ("Ole", "VarCyAdd", InvalidNumberOfArguments),
    ("Ole", "VarCyFix", InvalidNumberOfArguments),
    ("Ole", "VarCyFromBool", InvalidNumberOfArguments),
    ("Ole", "VarCyFromDate", InvalidNumberOfArguments),
    ("Ole", "VarCyFromI1", InvalidNumberOfArguments),
    ("Ole", "VarCyFromI2", InvalidNumberOfArguments),
    ("Ole", "VarCyFromI4", InvalidNumberOfArguments),
    ("Ole", "VarCyFromI8", InvalidNumberOfArguments),
    ("Ole", "VarCyFromR4", InvalidNumberOfArguments),
    ("Ole", "VarCyFromR8", InvalidNumberOfArguments),
    ("Ole", "VarCyFromStr", InvalidNumberOfArguments),
    ("Ole", "VarCyFromUI1", InvalidNumberOfArguments),
    ("Ole", "VarCyFromUI2", InvalidNumberOfArguments),
    ("Ole", "VarCyFromUI4", InvalidNumberOfArguments),
    ("Ole", "VarCyFromUI8", InvalidNumberOfArguments),
    ("Ole", "VarCyInt", InvalidNumberOfArguments),
    ("Ole", "VarCyMul", InvalidNumberOfArguments),
    ("Ole", "VarCyMulI4", InvalidNumberOfArguments),
    ("Ole", "VarCyMulI8", InvalidNumberOfArguments),
    ("Ole", "VarCyNeg", InvalidNumberOfArguments),
    ("Ole", "VarCyRound", InvalidNumberOfArguments),
    ("Ole", "VarCySub", InvalidNumberOfArguments),
    ("Ole", "VarDateFromBool", InvalidNumberOfArguments),
    ("Ole", "VarDateFromCy", InvalidNumberOfArguments),
    ("Ole", "VarDateFromI1", InvalidNumberOfArguments),
    ("Ole", "VarDateFromI2", InvalidNumberOfArguments),
    ("Ole", "VarDateFromI4", InvalidNumberOfArguments),
    ("Ole", "VarDateFromI8", InvalidNumberOfArguments),
    ("Ole", "VarDateFromR4", InvalidNumberOfArguments),
    ("Ole", "VarDateFromR8", InvalidNumberOfArguments),
    ("Ole", "VarDateFromStr", InvalidNumberOfArguments),
    ("Ole", "VarDateFromUI1", InvalidNumberOfArguments),
    ("Ole", "VarDateFromUI2", InvalidNumberOfArguments),
    ("Ole", "VarDateFromUI4", InvalidNumberOfArguments),
    ("Ole", "VarDateFromUI8", InvalidNumberOfArguments),
    ("Ole", "VarDecFromBool", InvalidNumberOfArguments),
    ("Ole", "VarDecFromCy", InvalidNumberOfArguments),
    ("Ole", "VarDecFromDate", InvalidNumberOfArguments),
    ("Ole", "VarDecFromI1", InvalidNumberOfArguments),
    ("Ole", "VarDecFromI2", InvalidNumberOfArguments),
    ("Ole", "VarDecFromI4", InvalidNumberOfArguments),
    ("Ole", "VarDecFromI8", InvalidNumberOfArguments),
    ("Ole", "VarDecFromR4", InvalidNumberOfArguments),
    ("Ole", "VarDecFromR8", InvalidNumberOfArguments),
    ("Ole", "VarDecFromStr", InvalidNumberOfArguments),
    ("Ole", "VarDecFromUI1", InvalidNumberOfArguments),
    ("Ole", "VarDecFromUI2", InvalidNumberOfArguments),
    ("Ole", "VarDecFromUI4", InvalidNumberOfArguments),
    ("Ole", "VarDecFromUI8", InvalidNumberOfArguments),
    ("Ole", "VarI1FromBool", CrashesWindows),
    ("Ole", "VarI1FromCy", CrashesWindows),
    ("Ole", "VarI1FromDate", CrashesWindows),
    ("Ole", "VarI1FromI2", CrashesWindows),
    ("Ole", "VarI1FromI4", CrashesWindows),
    ("Ole", "VarI1FromI8", CrashesWindows),
    ("Ole", "VarI1FromR4", CrashesWindows),
    ("Ole", "VarI1FromR8", CrashesWindows),
    ("Ole", "VarI1FromUI1", CrashesWindows),
    ("Ole", "VarI1FromUI2", CrashesWindows),
    ("Ole", "VarI1FromUI4", CrashesWindows),
    ("Ole", "VarI1FromUI8", CrashesWindows),
    ("Ole", "VarI2FromBool", InvalidNumberOfArguments),
    ("Ole", "VarI2FromDate", InvalidNumberOfArguments),
    ("Ole", "VarI2FromI1", InvalidNumberOfArguments),
    ("Ole", "VarI2FromI4", InvalidNumberOfArguments),
    ("Ole", "VarI2FromI8", InvalidNumberOfArguments),
    ("Ole", "VarI2FromR4", InvalidNumberOfArguments),
    ("Ole", "VarI2FromR8", InvalidNumberOfArguments),
    ("Ole", "VarI2FromStr", InvalidNumberOfArguments),
    ("Ole", "VarI2FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarI2FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarI2FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarI2FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarI4FromBool", InvalidNumberOfArguments),
    ("Ole", "VarI4FromCy", InvalidNumberOfArguments),
    ("Ole", "VarI4FromDate", InvalidNumberOfArguments),
    ("Ole", "VarI4FromI1", InvalidNumberOfArguments),
    ("Ole", "VarI4FromI2", InvalidNumberOfArguments),
    ("Ole", "VarI4FromI8", InvalidNumberOfArguments),
    ("Ole", "VarI4FromR4", InvalidNumberOfArguments),
    ("Ole", "VarI4FromR8", InvalidNumberOfArguments),
    ("Ole", "VarI4FromStr", InvalidNumberOfArguments),
    ("Ole", "VarI4FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarI4FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarI4FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarI4FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarI8FromBool", InvalidNumberOfArguments),
    ("Ole", "VarI8FromCy", InvalidNumberOfArguments),
    ("Ole", "VarI8FromDate", InvalidNumberOfArguments),
    ("Ole", "VarI8FromI1", InvalidNumberOfArguments),
    ("Ole", "VarI8FromI2", InvalidNumberOfArguments),
    ("Ole", "VarI8FromR4", InvalidNumberOfArguments),
    ("Ole", "VarI8FromR8", InvalidNumberOfArguments),
    ("Ole", "VarI8FromStr", InvalidNumberOfArguments),
    ("Ole", "VarI8FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarI8FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarI8FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarI8FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarI8FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarMonthName", InvalidNumberOfArguments),
    ("Ole", "VarR4FromBool", InvalidNumberOfArguments),
    ("Ole", "VarR4FromDate", InvalidNumberOfArguments),
    ("Ole", "VarR4FromI1", InvalidNumberOfArguments),
    ("Ole", "VarR4FromI2", InvalidNumberOfArguments),
    ("Ole", "VarR4FromI4", InvalidNumberOfArguments),
    ("Ole", "VarR4FromI8", InvalidNumberOfArguments),
    ("Ole", "VarR4FromR8", InvalidNumberOfArguments),
    ("Ole", "VarR4FromStr", InvalidNumberOfArguments),
    ("Ole", "VarR4FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarR4FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarR4FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarR4FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarR8FromBool", InvalidNumberOfArguments),
    ("Ole", "VarR8FromDate", InvalidNumberOfArguments),
    ("Ole", "VarR8FromI2", InvalidNumberOfArguments),
    ("Ole", "VarR8FromI4", InvalidNumberOfArguments),
    ("Ole", "VarR8FromI8", InvalidNumberOfArguments),
    ("Ole", "VarR8FromR4", InvalidNumberOfArguments),
    ("Ole", "VarR8FromStr", InvalidNumberOfArguments),
    ("Ole", "VarR8FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarR8FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarR8FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarR8FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarR8Pow", InvalidNumberOfArguments),
    ("Ole", "VarR8Round", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromBool", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromCy", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromDate", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromI1", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromI2", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromI4", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromI8", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromR4", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromR8", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromStr", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarUI1FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromBool", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromCy", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromDate", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromI1", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromI2", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromI4", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromI8", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromR4", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromStr", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarUI2FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromBool", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromCy", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromDate", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromI1", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromI2", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromI4", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromI8", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromR4", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromR8", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromStr", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarUI4FromUI8", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromBool", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromCy", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromDate", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromI1", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromI2", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromI8", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromR4", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromR8", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromStr", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromUI1", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromUI2", InvalidNumberOfArguments),
    ("Ole", "VarUI8FromUI4", InvalidNumberOfArguments),
    ("Ole", "VarUdateFromDate", InvalidNumberOfArguments),
    ("Ole", "VarWeekdayName", InvalidNumberOfArguments),
    ("P2P", "PeerCollabExportContact", InvalidNumberOfArguments),
    ("P2P", "PeerCollabGetEndpointName", InvalidNumberOfArguments),
    ("P2P", "PeerCollabGetSigninOptions", InvalidNumberOfArguments),
    ("P2P", "PeerCreatePeerName", InvalidNumberOfArguments),
    ("P2P", "PeerHostNameToPeerName", InvalidNumberOfArguments),
    ("P2P", "PeerIdentityCreate", InvalidNumberOfArguments),
    ("P2P", "PeerIdentityExport", InvalidNumberOfArguments),
    ("P2P", "PeerIdentityGetCryptKey", InvalidNumberOfArguments),
    ("P2P", "PeerIdentityGetDefault", InvalidNumberOfArguments),
    ("P2P", "PeerIdentityGetFriendlyName", InvalidNumberOfArguments),
    ("P2P", "PeerIdentityGetXML", InvalidNumberOfArguments),
    ("P2P", "PeerIdentityImport", InvalidNumberOfArguments),
    ("P2P", "PeerNameToPeerHostName", InvalidNumberOfArguments),
    ("Performance", "BackupPerfRegistryToFileW", NotImplementedLinux),
    ("Performance", "PdhCloseLog", NotImplementedLinux),
    ("Performance", "PdhCloseQuery", CrashesLinux),
    ("Performance", "PdhCollectQueryData", CrashesLinux),
    ("Performance", "PdhCollectQueryDataEx", CrashesLinux),
    ("Performance", "PdhCollectQueryDataWithTime", CrashesLinux),
    ("Performance", "PdhConnectMachineA", NotImplementedLinux),
    ("Performance", "PdhConnectMachineW", NotImplementedLinux),
    ("Performance", "PdhCreateSQLTablesA", NotImplementedLinux),
    ("Performance", "PdhCreateSQLTablesW", NotImplementedLinux),
    ("Performance", "PdhEnumLogSetNamesA", NotImplementedLinux),
    ("Performance", "PdhEnumLogSetNamesW", NotImplementedLinux),
    ("Performance", "PdhEnumMachinesA", NotImplementedLinux),
    ("Performance", "PdhEnumMachinesHA", NotImplementedLinux),
    ("Performance", "PdhEnumMachinesHW", NotImplementedLinux),
    ("Performance", "PdhEnumMachinesW", NotImplementedLinux),
    ("Performance", "PdhEnumObjectItemsHA", NotImplementedLinux),
    ("Performance", "PdhEnumObjectItemsHW", NotImplementedLinux),
    ("Performance", "PdhEnumObjectsA", NotImplementedLinux),
    ("Performance", "PdhEnumObjectsHA", NotImplementedLinux),
    ("Performance", "PdhEnumObjectsHW", NotImplementedLinux),
    ("Performance", "PdhEnumObjectsW", NotImplementedLinux),
    ("Performance", "PdhExpandWildCardPathHA", NotImplementedLinux),
    ("Performance", "PdhExpandWildCardPathHW", NotImplementedLinux),
    ("Performance", "PdhGetCounterInfoA", CrashesWindows),
    ("Performance", "PdhGetCounterInfoW", CrashesWindows),
    ("Performance", "PdhGetCounterTimeBase", CrashesLinux),
    ("Performance", "PdhGetDataSourceTimeRangeA", CrashesWindows),
    ("Performance", "PdhGetDataSourceTimeRangeH", CrashesWindows),
    ("Performance", "PdhGetDataSourceTimeRangeW", CrashesWindows),
    ("Performance", "PdhGetDefaultPerfCounterA", NotImplementedLinux),
    ("Performance", "PdhGetDefaultPerfCounterHA", NotImplementedLinux),
    ("Performance", "PdhGetDefaultPerfCounterHW", NotImplementedLinux),
    ("Performance", "PdhGetDefaultPerfCounterW", NotImplementedLinux),
    ("Performance", "PdhGetDefaultPerfObjectA", NotImplementedLinux),
    ("Performance", "PdhGetDefaultPerfObjectHA", NotImplementedLinux),
    ("Performance", "PdhGetDefaultPerfObjectHW", NotImplementedLinux),
    ("Performance", "PdhGetDefaultPerfObjectW", NotImplementedLinux),
    ("Performance", "PdhGetFormattedCounterArrayA", CrashesWindows),
    ("Performance", "PdhGetFormattedCounterArrayW", CrashesWindows),
    ("Performance", "PdhGetLogFileSize", NotImplementedLinux),
    ("Performance", "PdhGetLogSetGUID", NotImplementedLinux),
    ("Performance", "PdhGetRawCounterArrayA", CrashesWindows),
    ("Performance", "PdhGetRawCounterArrayW", CrashesWindows),
    ("Performance", "PdhIsRealTimeQuery", NotImplementedLinux),
    ("Performance", "PdhOpenQueryH", NotImplementedLinux),
    ("Performance", "PdhParseCounterPathA", CrashesWindows),
    ("Performance", "PdhParseCounterPathW", CrashesWindows),
    ("Performance", "PdhParseInstanceNameA", NotImplementedLinux),
    ("Performance", "PdhParseInstanceNameW", NotImplementedLinux),
    ("Performance", "PdhReadRawLogRecord", CrashesWindows),
    ("Performance", "PdhRemoveCounter", CrashesLinux),
    ("Performance", "PdhSetCounterScaleFactor", CrashesLinux),
    ("Performance", "PdhSetLogSetRunID", NotImplementedLinux),
    ("Performance", "PdhUpdateLogA", NotImplementedLinux),
    ("Performance", "PdhUpdateLogFileCatalog", NotImplementedLinux),
    ("Performance", "PdhUpdateLogW", NotImplementedLinux),
    ("Performance", "PdhVerifySQLDBA", NotImplementedLinux),
    ("Performance", "PdhVerifySQLDBW", NotImplementedLinux),
    ("Performance", "PerfCloseQueryHandle", NotImplementedLinux),
    ("Performance", "PerfEnumerateCounterSet", CrashesWindows),
    ("Performance", "PerfQueryCounterData", CrashesWindows),
    ("Performance", "PerfQueryCounterInfo", CrashesWindows),
    ("Performance", "RestorePerfRegistryFromFileW", NotImplementedLinux),
    ("Performance", "SetServiceAsTrustedA", NotImplementedLinux),
    ("Performance", "SetServiceAsTrustedW", NotImplementedLinux),
    ("Performance", "UpdatePerfNameFilesA", NotImplementedLinux),
    ("Performance", "UpdatePerfNameFilesW", NotImplementedLinux),
    ("Pipes", "GetNamedPipeClientComputerNameA", NotImplementedLinux),
    ("Pipes", "GetNamedPipeClientComputerNameW", NotImplementedLinux),
    ("Pipes", "WaitNamedPipeW", CrashesWindows),
    ("Pnp", "SwDeviceClose", CrashesWindows),
    ("Pnp", "SwDeviceGetLifetime", InvalidNumberOfArguments),
    ("Pnp", "SwDeviceInterfaceSetState", CrashesWindows),
    ("Pnp", "SwDeviceSetLifetime", CrashesWindows),
    ("Pointer", "GetPointerCursorId", NotImplementedLinux),
    ("Pointer", "GetUnpredictedMessagePos", NotImplementedLinux),
    ("Pointer", "IsMouseInPointerEnabled", NotImplementedLinux),
    ("Pointer", "SkipPointerFrameMessages", NotImplementedLinux),
    ("Power", "DevicePowerClose", NotImplementedLinux),
    ("Power", "DevicePowerEnumDevices", NotImplementedLinux),
    ("Power", "DevicePowerOpen", NotImplementedLinux),
    ("Power", "PowerOpenSystemPowerKey", NotImplementedLinux),
    ("Power", "PowerOpenUserPowerKey", NotImplementedLinux),
    ("Power", "PowerReplaceDefaultPowerSchemes", NotImplementedLinux),
    ("Power", "PowerRestoreDefaultPowerSchemes", NotImplementedLinux),
    ("Power", "RegisterSuspendResumeNotification", NotImplementedLinux),
    ("PrintTicket", "PTOpenProvider", InvalidNumberOfArguments),
    ("PrintTicket", "PTQuerySchemaVersionSupport", InvalidNumberOfArguments),
    ("Printing", "AddPrintDeviceObject", InvalidNumberOfArguments),
    ("Printing", "CloseSpoolFileHandle", NotImplementedLinux),
    ("Printing", "CommitSpoolData", NotImplementedLinux),
    ("Printing", "ConnectToPrinterDlg", ShowsDialogWindows),
    ("Printing", "CorePrinterDriverInstalledA", InvalidNumberOfArguments),
    ("Printing", "CorePrinterDriverInstalledW", InvalidNumberOfArguments),
    ("Printing", "DeleteJobNamedProperty", NotImplementedLinux),
    ("Printing", "DeletePrinterDataA", NotImplementedLinux),
    ("Printing", "DeletePrinterDataW", NotImplementedLinux),
    ("Printing", "DeletePrinterDriverPackageA", NotImplementedLinux),
    ("Printing", "DeletePrinterDriverPackageW", NotImplementedLinux),
    ("Printing", "DeletePrinterIC", NotImplementedLinux),
    ("Printing", "DeletePrinterKeyA", NotImplementedLinux),
    ("Printing", "DeletePrinterKeyW", NotImplementedLinux),
    ("Printing", "EnumPortsW", CrashesWindows),
    ("Printing", "EnumPrintersW", CrashesLinux),
    ("Printing", "EnumPrintersW", CrashesLinux),
    ("Printing", "GdiDeleteSpoolFileHandle", NotImplementedLinux),
    ("Printing", "GdiEndDocEMF", NotImplementedLinux),
    ("Printing", "GdiEndPageEMF", NotImplementedLinux),
    ("Printing", "GdiGetDC", NotImplementedLinux),
    ("Printing", "GdiGetPageCount", NotImplementedLinux),
    ("Printing", "GdiGetPageHandle", NotImplementedLinux),
    ("Printing", "GdiPlayPageEMF", NotImplementedLinux),
    ("Printing", "GdiStartPageEMF", NotImplementedLinux),
    ("Printing", "GetPrintOutputInfo", NotImplementedLinux),
    ("Printing", "GetPrinterDriver2A", NotImplementedLinux),
    ("Printing", "GetPrinterDriver2W", NotImplementedLinux),
    ("Printing", "GetPrinterDriverA", CrashesLinux),
    ("Printing", "GetPrinterDriverA", CrashesLinux),
    ("Printing", "GetPrinterDriverPackagePathA", NotImplementedLinux),
    ("Printing", "GetPrinterDriverPackagePathW", NotImplementedLinux),
    ("Printing", "GetPrinterDriverW", CrashesLinux),
    ("Printing", "GetPrinterDriverW", CrashesLinux),
    ("Printing", "GetSpoolFileHandle", NotImplementedLinux),
    ("Printing", "InstallPrinterDriverFromPackageA", NotImplementedLinux),
    ("Printing", "InstallPrinterDriverFromPackageW", NotImplementedLinux),
    ("Printing", "PrinterMessageBoxA", NotImplementedLinux),
    ("Printing", "PrinterMessageBoxW", NotImplementedLinux),
    ("Printing", "ProvidorFindClosePrinterChangeNotification", NotImplementedLinux),
    ("Printing", "RemovePrintDeviceObject", NotImplementedLinux),
    ("Printing", "RouterAllocBidiMem", CrashesWindows),
    ("Printing", "RouterAllocBidiResponseContainer", NotImplementedLinux),
    ("Printing", "RouterAllocPrinterNotifyInfo", NotImplementedLinux),
    ("Printing", "SHRegSetPathA", CrashesWindows),
    ("Printing", "SplIsSessionZero", NotImplementedLinux),
    ("Printing", "SpoolerFindClosePrinterChangeNotification", NotImplementedLinux),
    ("Printing", "UnRegisterForPrintAsyncNotifications", NotImplementedLinux),
    ("Printing", "UpdatePrintDeviceObject", NotImplementedLinux),
    ("Printing", "WaitForPrinterChange", NotImplementedLinux),
    ("ProcessStatus", "K32EnumProcesses", CrashesWindows),
    ("PropertiesSystem", "ClearPropVariantArray", CrashesWindows),
    ("PropertiesSystem", "ClearVariantArray", CrashesWindows),
    ("PropertiesSystem", "InitPropVariantFromResource", InvalidNumberOfArguments),
    ("PropertiesSystem", "InitPropVariantFromStringAsVector", InvalidNumberOfArguments),
    ("PropertiesSystem", "InitVariantFromResource", InvalidNumberOfArguments),
    ("PropertiesSystem", "PSGetPropertyKeyFromName", InvalidNumberOfArguments),
    ("PropertiesSystem", "PSLookupPropertyHandlerCLSID", InvalidNumberOfArguments),
    ("PropertiesSystem", "PSPropertyKeyFromString", InvalidNumberOfArguments),
    ("PropertiesSystem", "PifMgr_CloseProperties", NotImplementedLinux),
    ("PropertiesSystem", "PifMgr_OpenProperties", NotImplementedLinux),
    ("QoS", "QOSCloseHandle", NotImplementedLinux),
    ("QoS", "TcCloseInterface", NotImplementedLinux),
    ("QoS", "TcDeleteFilter", NotImplementedLinux),
    ("QoS", "TcDeleteFlow", NotImplementedLinux),
    ("QoS", "TcGetFlowNameA", NotImplementedLinux),
    ("QoS", "TcGetFlowNameW", NotImplementedLinux),
    ("QoS", "TcOpenInterfaceA", NotImplementedLinux),
    ("QoS", "TcOpenInterfaceW", NotImplementedLinux),
    ("Recovery", "ApplicationRecoveryInProgress", InvalidNumberOfArguments),
    ("Recovery", "UnregisterApplicationRecoveryCallback", NotImplementedLinux),
    ("Registry", "RegConnectRegistryExA", NotImplementedLinux),
    ("Registry", "RegConnectRegistryExW", NotImplementedLinux),
    ("Registry", "RegDisablePredefinedCacheEx", NotImplementedLinux),
    ("RemoteDesktop", "WTSGetChildSessionId", NotImplementedLinux),
    ("RemoteDesktop", "WTSIsChildSessionsEnabled", NotImplementedLinux),
    ("RemoteDesktop", "WTSWaitSystemEvent", Freeze),
    ("RemoteManagement", "RmCancelCurrentTask", NotImplementedLinux),
    ("RemoteManagement", "RmGetFilterList", NotImplementedLinux),
    ("RemoteManagement", "RmJoinSession", NotImplementedLinux),
    ("RestartManager", "RmCancelCurrentTask", NotImplementedLinux),
    ("RestartManager", "RmGetFilterList", NotImplementedLinux),
    ("RestartManager", "RmJoinSession", NotImplementedLinux),
    ("RightsManagement", "DRMAddLicense", NotImplementedLinux),
    ("RightsManagement", "DRMAddRightWithUser", NotImplementedLinux),
    ("RightsManagement", "DRMCheckSecurity", CrashesWindows),
    ("RightsManagement", "DRMClearAllRights", NotImplementedLinux),
    ("RightsManagement", "DRMCloseEnvironmentHandle", NotImplementedLinux),
    ("RightsManagement", "DRMCloseHandle", NotImplementedLinux),
    ("RightsManagement", "DRMClosePubHandle", NotImplementedLinux),
    ("RightsManagement", "DRMCloseQueryHandle", NotImplementedLinux),
    ("RightsManagement", "DRMCloseSession", NotImplementedLinux),
    ("RightsManagement", "DRMCreateEnablingBitsDecryptor", NotImplementedLinux),
    ("RightsManagement", "DRMCreateEnablingBitsEncryptor", NotImplementedLinux),
    ("RightsManagement", "DRMCreateLicenseStorageSession", NotImplementedLinux),
    ("RightsManagement", "DRMCreateUser", NotImplementedLinux),
    ("RightsManagement", "DRMDecode", NotImplementedLinux),
    ("RightsManagement", "DRMDeconstructCertificateChain", NotImplementedLinux),
    ("RightsManagement", "DRMDecrypt", NotImplementedLinux),
    ("RightsManagement", "DRMDeleteLicense", NotImplementedLinux),
    ("RightsManagement", "DRMDuplicateEnvironmentHandle", NotImplementedLinux),
    ("RightsManagement", "DRMDuplicateHandle", NotImplementedLinux),
    ("RightsManagement", "DRMDuplicatePubHandle", NotImplementedLinux),
    ("RightsManagement", "DRMDuplicateSession", NotImplementedLinux),
    ("RightsManagement", "DRMEncode", NotImplementedLinux),
    ("RightsManagement", "DRMEncrypt", NotImplementedLinux),
    ("RightsManagement", "DRMEnumerateLicense", NotImplementedLinux),
    ("RightsManagement", "DRMGetApplicationSpecificData", NotImplementedLinux),
    ("RightsManagement", "DRMGetBoundLicenseAttributeCount", NotImplementedLinux),
    ("RightsManagement", "DRMGetBoundLicenseObject", NotImplementedLinux),
    ("RightsManagement", "DRMGetBoundLicenseObjectCount", NotImplementedLinux),
    ("RightsManagement", "DRMGetCertificateChainCount", NotImplementedLinux),
    ("RightsManagement", "DRMGetIntervalTime", NotImplementedLinux),
    ("RightsManagement", "DRMGetIssuanceLicenseTemplate", NotImplementedLinux),
    ("RightsManagement", "DRMGetMetaData", NotImplementedLinux),
    ("RightsManagement", "DRMGetNameAndDescription", NotImplementedLinux),
    ("RightsManagement", "DRMGetOwnerLicense", NotImplementedLinux),
    ("RightsManagement", "DRMGetRightExtendedInfo", NotImplementedLinux),
    ("RightsManagement", "DRMGetSecurityProvider", NotImplementedLinux),
    ("RightsManagement", "DRMGetServiceLocation", NotImplementedLinux),
    ("RightsManagement", "DRMGetUnboundLicenseAttributeCount", NotImplementedLinux),
    ("RightsManagement", "DRMGetUnboundLicenseObject", NotImplementedLinux),
    ("RightsManagement", "DRMGetUnboundLicenseObjectCount", NotImplementedLinux),
    ("RightsManagement", "DRMGetUserInfo", NotImplementedLinux),
    ("RightsManagement", "DRMGetUserRights", NotImplementedLinux),
    ("RightsManagement", "DRMGetUsers", NotImplementedLinux),
    ("RightsManagement", "DRMIsWindowProtected", NotImplementedLinux),
    ("RightsManagement", "DRMParseUnboundLicense", NotImplementedLinux),
    ("RightsManagement", "DRMRegisterProtectedWindow", NotImplementedLinux),
    ("RightsManagement", "DRMRegisterRevocationList", NotImplementedLinux),
    ("RightsManagement", "DRMRepair", NotImplementedLinux),
    ("RightsManagement", "DRMSetApplicationSpecificData", NotImplementedLinux),
    ("RightsManagement", "DRMSetIntervalTime", NotImplementedLinux),
    ("RightsManagement", "DRMSetMetaData", NotImplementedLinux),
    ("RightsManagement", "DRMSetNameAndDescription", NotImplementedLinux),
    ("Search", "ODBCGetTryWaitValue", NotImplementedLinux),
    ("Search", "ODBCSetTryWaitValue", NotImplementedLinux),
    ("Search", "SQLCloseEnumServers", CrashesWindows),
    ("Search", "SQLGetNextEnumeration", NotImplementedLinux),
    ("Search", "SQLInitEnumServers", NotImplementedLinux),
    ("Search", "dbprtypeA", NotImplementedLinux),
    ("Search", "dbprtypeW", NotImplementedLinux),
    ("Security", "CheckTokenCapability", NotImplementedLinux),
    ("Security", "CheckTokenMembershipEx", NotImplementedLinux),
    ("Security", "CopySid", CrashesWindows),
    ("Security", "EqualPrefixSid", CrashesWindows),
    ("Security", "EqualSid", CrashesWindows),
    ("Security", "GetCachedSigningLevel", NotImplementedLinux),
    ("Security", "GetLengthSid", CrashesWindows),
    ("Security", "QuerySecurityAccessMask", NotImplementedLinux),
    ("Security", "SetSecurityAccessMask", NotImplementedLinux),
    ("SecurityCenter", "WscGetAntiMalwareUri", InvalidNumberOfArguments),
    ("SerialCommunication", "ComDBClaimNextFreePort", CrashesWindows),
    ("SerialCommunication", "ComDBClaimPort", CrashesWindows),
    ("SerialCommunication", "ComDBClose", CrashesWindows),
    ("SerialCommunication", "ComDBGetCurrentPortUsage", CrashesWindows),
    ("SerialCommunication", "ComDBOpen", NotImplementedLinux),
    ("SerialCommunication", "ComDBReleasePort", CrashesWindows),
    ("Services", "GetServiceRegistryStateKey", NotImplementedWindows),
    ("Services", "GetSharedServiceDirectory", NotImplementedWindows),
    ("Services", "GetSharedServiceRegistryStateKey", NotImplementedWindows),
    ("Services", "RegisterServiceCtrlHandlerA", CrashesWindows),
    ("Services", "WaitServiceState", NotImplementedLinux),
    ("SetupAndMigration", "OOBEComplete", NotImplementedLinux),
    ("Shell", "AssocGetPerceivedType", CrashesWindows),
    ("Shell", "CommandLineToArgvW", CrashesWindows),
    ("Shell", "CreateProfile", NotImplementedLinux),
    ("Shell", "DeleteProfileA", NotImplementedLinux),
    ("Shell", "DeleteProfileW", NotImplementedLinux),
    ("Shell", "DoEnvironmentSubstA", CrashesWindows),
    ("Shell", "DoEnvironmentSubstW", CrashesWindows),
    ("Shell", "ExtractAssociatedIconExW", CrashesWindows),
    ("Shell", "ExtractAssociatedIconW", Freeze),
    ("Shell", "ExtractIconExA", CrashesWindows),
    ("Shell", "ExtractIconExW", CrashesWindows),
    ("Shell", "FindExecutableA", CrashesWindows),
    ("Shell", "FindExecutableW", CrashesWindows),
    ("Shell", "GetCurrentProcessExplicitAppUserModelID", InvalidNumberOfArguments),
    ("Shell", "GetFileNameFromBrowse", ShowsDialogLinux),
    ("Shell", "GetScaleFactorForMonitor", InvalidNumberOfArguments),
    ("Shell", "GetWindowSubclass", NotImplementedWindows),
    ("Shell", "HlinkCreateShortcutFromString", NotImplementedLinux),
    ("Shell", "HlinkGetSpecialReference", InvalidNumberOfArguments),
    ("Shell", "HlinkGetValueFromParams", InvalidNumberOfArguments),
    ("Shell", "HlinkResolveShortcutToString", NotImplementedLinux),
    ("Shell", "HlinkSetSpecialReference", NotImplementedLinux),
    ("Shell", "HlinkTranslateURL", InvalidNumberOfArguments),
    ("Shell", "PathAllocCanonicalize", InvalidNumberOfArguments),
    ("Shell", "PathAllocCombine", InvalidNumberOfArguments),
    ("Shell", "PathBuildRootW", CrashesWindows),
    ("Shell", "PathCchAddBackslash", CrashesWindows),
    ("Shell", "PathCchAddBackslashEx", CrashesWindows),
    ("Shell", "PathCchCanonicalize", CrashesWindows),
    ("Shell", "PathCchCanonicalizeEx", CrashesWindows),
    ("Shell", "PathCchFindExtension", InvalidNumberOfArguments),
    ("Shell", "PathCchRemoveBackslash", CrashesWindows),
    ("Shell", "PathCchRemoveBackslashEx", CrashesWindows),
    ("Shell", "PathCchSkipRoot", InvalidNumberOfArguments),
    ("Shell", "PathCleanupSpec", CrashesWindows),
    ("Shell", "PathIsExe", CrashesLinux),
    ("Shell", "PathIsSlowA", NotImplementedLinux),
    ("Shell", "PathIsSlowW", NotImplementedLinux),
    ("Shell", "PathIsUNCEx", CrashesWindows),
    ("Shell", "PathMatchSpecA", CrashesLinux),
    ("Shell", "PathMatchSpecExA", NotImplementedLinux),
    ("Shell", "PathMatchSpecExW", NotImplementedLinux),
    ("Shell", "PathMatchSpecExW", NotImplementedLinux),
    ("Shell", "PathMatchSpecW", CrashesLinux),
    ("Shell", "PathQualify", CrashesWindows),
    ("Shell", "PathUnExpandEnvStringsW", CrashesLinux),
    ("Shell", "PathYetAnotherMakeUniqueName", CrashesLinux),
    ("Shell", "RegisterScaleChangeEvent", InvalidNumberOfArguments),
    ("Shell", "RegisterScaleChangeNotifications", InvalidNumberOfArguments),
    ("Shell", "RestartDialog", ShowsDialogWindows),
    ("Shell", "RestartDialogEx", Other),
    ("Shell", "SHAnsiToAnsi", CrashesWindows),
    ("Shell", "SHCLSIDFromString", InvalidNumberOfArguments),
    ("Shell", "SHDefExtractIconW", CrashesWindows),
    ("Shell", "SHEmptyRecycleBinA", ShowsDialogWindows),
    ("Shell", "SHEmptyRecycleBinW", ShowsDialogLinux),
    ("Shell", "SHEvaluateSystemCommandTemplate", CrashesWindows),
    ("Shell", "SHFind_InitMenuPopup", Freeze),
    ("Shell", "SHGetDriveMedia", InvalidNumberOfArguments),
    ("Shell", "SHGetNewLinkInfoA", CrashesWindows),
    ("Shell", "SHGetNewLinkInfoW", CrashesWindows),
    ("Shell", "SHGetUnreadMailCountW", NotImplementedLinux),
    ("Shell", "SHInvokePrinterCommandA", NotImplementedLinux),
    ("Shell", "SHInvokePrinterCommandW", NotImplementedLinux),
    ("Shell", "SHIsFileAvailableOffline", InvalidNumberOfArguments),
    ("Shell", "SHMessageBoxCheckA", ShowsDialogWindows),
    ("Shell", "SHMessageBoxCheckW", ShowsDialogWindows),
    ("Shell", "SHMessageBoxCheckW", ShowsDialogWindows),
    ("Shell", "SHRegCloseUSKey", CrashesWindows),
    ("Shell", "SHRegCreateUSKeyW", CrashesWindows),
    ("Shell", "SHRegGetBoolUSValueA", CrashesLinux),
    ("Shell", "SHRegGetBoolUSValueW", CrashesWindows),
    ("Shell", "SHRegOpenUSKeyA", CrashesLinux),
    ("Shell", "SHRegOpenUSKeyW", CrashesWindows),
    ("Shell", "SHRegSetPathA", CrashesWindows),
    ("Shell", "SHRegSetPathW", CrashesWindows),
    ("Shell", "SHSetFolderPathA", NotImplementedLinux),
    ("Shell", "SHSetFolderPathW", NotImplementedLinux),
    ("Shell", "SHSimpleIDListFromPath", CrashesWindows),
    ("Shell", "SHStartNetConnectionDialogW", NotImplementedLinux),
    ("Shell", "SHStrDupA", InvalidNumberOfArguments),
    ("Shell", "SHStrDupW", InvalidNumberOfArguments),
    ("Shell", "SHStripMneumonicA", CrashesWindows),
    ("Shell", "SHStripMneumonicW", CrashesWindows),
    ("Shell", "SHTestTokenMembership", NotImplementedLinux),
    ("Shell", "SHUnicodeToUnicode", CrashesWindows),
    ("Shell", "SetCurrentProcessExplicitAppUserModelID", CrashesWindows),
    ("Shell", "ShellAboutA", ShowsDialogLinux),
    ("Shell", "ShellAboutW", ShowsDialogLinux),
    ("Shell", "ShellMessageBoxA", NotImplementedLinux),
    ("Shell", "ShellMessageBoxW", NotImplementedLinux),
    ("Shell", "Shell_GetCachedImageIndex", CrashesWindows),
    ("Shell", "Shell_GetCachedImageIndexA", NotImplementedLinux),
    ("Shell", "Shell_GetCachedImageIndexW", CrashesWindows),
    ("Shell", "StrCatChainW", CrashesWindows),
    ("Shell", "StrChrNIW", NotImplementedLinux),
    ("Shell", "StrCmpCA", CrashesWindows),
    ("Shell", "StrCmpCW", CrashesWindows),
    ("Shell", "StrCmpICA", CrashesWindows),
    ("Shell", "StrCmpICW", CrashesWindows),
    ("Shell", "StrCmpNCA", CrashesWindows),
    ("Shell", "StrCmpNCW", CrashesWindows),
    ("Shell", "StrCmpNICA", CrashesWindows),
    ("Shell", "StrCmpNICW", CrashesWindows),
    ("Shell", "StrCpyNW", CrashesWindows),
    ("Shell", "UnregisterScaleChangeEvent", NotImplementedLinux),
    ("Shell", "UrlCompareA", CrashesLinux),
    ("Shell", "UrlFixupW", CrashesWindows),
    ("Shell", "UrlGetLocationA", CrashesLinux),
    ("Shell", "UrlGetLocationW", CrashesLinux),
    ("Shell", "UrlHashW", CrashesLinux),
    ("Shell", "WinHelpA", ShowsDialogWindows),
    ("Shell", "WinHelpW", ShowsDialogWindows),
    ("Shell", "wnsprintfA", CrashesWindows),
    ("Shell", "wnsprintfW", CrashesWindows),
    ("Snmp", "SnmpCancelMsg", NotImplementedLinux),
    ("Snmp", "SnmpCleanupEx", NotImplementedLinux),
    ("Snmp", "SnmpClose", NotImplementedLinux),
    ("Snmp", "SnmpCountVbl", NotImplementedLinux),
    ("Snmp", "SnmpDeleteVb", NotImplementedLinux),
    ("Snmp", "SnmpDuplicatePdu", NotImplementedLinux),
    ("Snmp", "SnmpDuplicateVbl", NotImplementedLinux),
    ("Snmp", "SnmpEntityToStr", NotImplementedLinux),
    ("Snmp", "SnmpFreeContext", NotImplementedLinux),
    ("Snmp", "SnmpFreeEntity", NotImplementedLinux),
    ("Snmp", "SnmpFreePdu", NotImplementedLinux),
    ("Snmp", "SnmpFreeVbl", NotImplementedLinux),
    ("Snmp", "SnmpGetLastError", NotImplementedLinux),
    ("Snmp", "SnmpGetRetry", NotImplementedLinux),
    ("Snmp", "SnmpGetTimeout", NotImplementedLinux),
    ("Snmp", "SnmpListenEx", NotImplementedLinux),
    ("Snmp", "SnmpMgrOidToStr", NotImplementedLinux),
    ("Snmp", "SnmpMgrOpen", NotImplementedLinux),
    ("Snmp", "SnmpMgrStrToOid", NotImplementedLinux),
    ("Snmp", "SnmpRecvMsg", NotImplementedLinux),
    ("Snmp", "SnmpSendMsg", NotImplementedLinux),
    ("Snmp", "SnmpSetPort", NotImplementedLinux),
    ("Snmp", "SnmpSetRetry", NotImplementedLinux),
    ("Snmp", "SnmpSetTimeout", NotImplementedLinux),
    ("Snmp", "SnmpStrToEntity", NotImplementedLinux),
    ("StationsAndDesktops", "EnumDesktopWindows", CrashesWindows),
    ("StationsAndDesktops", "EnumDesktopsA", CrashesWindows),
    ("StationsAndDesktops", "EnumDesktopsW", CrashesWindows),
    ("StationsAndDesktops", "EnumWindowStationsA", CrashesWindows),
    ("StationsAndDesktops", "EnumWindowStationsW", CrashesWindows),
    ("StructuredStorage", "FreePropVariantArray", CrashesWindows),
    ("StructuredStorage", "PropStgNameToFmtId", InvalidNumberOfArguments),
    ("SubsystemForLinux", "WslLaunch", InvalidNumberOfArguments),
    ("SubsystemForLinux", "WslLaunchInteractive", InvalidNumberOfArguments),
    ("SystemInformation", "GetIntegratedDisplaySize", InvalidNumberOfArguments),
    ("SystemInformation", "IsWow64GuestMachineSupported", InvalidNumberOfArguments),
    ("TabletPC", "Process", Other),
    ("Tapi", "lineBlindTransferW", NotImplementedLinux),
    ("Tapi", "lineCreateAgentA", NotImplementedLinux),
    ("Tapi", "lineCreateAgentSessionA", NotImplementedLinux),
    ("Tapi", "lineCreateAgentSessionW", NotImplementedLinux),
    ("Tapi", "lineCreateAgentW", NotImplementedLinux),
    ("Tapi", "lineGatherDigitsW", NotImplementedLinux),
    ("Tapi", "lineGenerateDigitsW", NotImplementedLinux),
    ("Tapi", "lineGetAddressIDW", NotImplementedLinux),
    ("Tapi", "lineGetDevConfigW", NotImplementedLinux),
    ("Tapi", "lineGetIconW", NotImplementedLinux),
    ("Tapi", "lineHandoffW", NotImplementedLinux),
    ("Tapi", "lineParkW", NotImplementedLinux),
    ("Tapi", "linePickupW", NotImplementedLinux),
    ("Tapi", "lineProxyMessage", NotImplementedLinux),
    ("Tapi", "lineRedirectW", NotImplementedLinux),
    ("Tapi", "lineSetAgentActivity", NotImplementedLinux),
    ("Tapi", "lineSetAgentMeasurementPeriod", NotImplementedLinux),
    ("Tapi", "lineSetAgentSessionState", NotImplementedLinux),
    ("Tapi", "lineSetAgentState", NotImplementedLinux),
    ("Tapi", "lineSetAgentStateEx", NotImplementedLinux),
    ("Tapi", "lineSetCallTreatment", NotImplementedLinux),
    ("Tapi", "lineSetLineDevStatus", NotImplementedLinux),
    ("Tapi", "lineSetQueueMeasurementPeriod", NotImplementedLinux),
    ("Tapi", "lineSetTollListW", NotImplementedLinux),
    ("Tapi", "lineUnparkW", NotImplementedLinux),
    ("Tapi", "phoneConfigDialogW", NotImplementedLinux),
    ("Tapi", "phoneGetIDW", NotImplementedLinux),
    ("Tapi", "phoneGetIconW", NotImplementedLinux),
    ("Tapi", "tapiRequestDrop", NotImplementedLinux),
    ("Tapi", "tapiRequestMakeCallW", NotImplementedLinux),
    ("Tapi", "tapiRequestMediaCall", NotImplementedLinux),
    ("Tapi", "tapiRequestMediaCallA", NotImplementedLinux),
    ("Tapi", "tapiRequestMediaCallW", NotImplementedLinux),
    ("TextServices", "DoMsCtfMonitor", NotImplementedLinux),
    ("TextServices", "UninitLocalMsCtfMonitor", NotImplementedLinux),
    ("Threading", "AddIntegrityLabelToBoundaryDescriptor", NotImplementedLinux),
    ("Threading", "AddSIDToBoundaryDescriptor", NotImplementedLinux),
    ("Threading", "AvRtDeleteThreadOrderingGroup", NotImplementedLinux),
    ("Threading", "AvRtLeaveThreadOrderingGroup", NotImplementedLinux),
    ("Threading", "AvRtWaitOnThreadOrderingGroup", NotImplementedLinux),
    ("Threading", "AvSetMmMaxThreadCharacteristicsA", CrashesWindows),
    ("Threading", "AvSetMmMaxThreadCharacteristicsW", CrashesWindows),
    ("Threading", "AvSetMmThreadCharacteristicsA", CrashesWindows),
    ("Threading", "AvSetMmThreadCharacteristicsW", CrashesWindows),
    ("Threading", "ChangeTimerQueueTimer", CrashesLinux),
    ("Threading", "CloseThreadpool", CrashesWindows),
    ("Threading", "CloseThreadpoolCleanupGroup", CrashesWindows),
    ("Threading", "CreateBoundaryDescriptorA", NotImplementedLinux),
    ("Threading", "EnterCriticalSection", Freeze),
    ("Threading", "EnterSynchronizationBarrier", CrashesWindows),
    ("Threading", "ExitProcess", CrashAutomatic),
    ("Threading", "ExitThread", CrashAutomatic),
    ("Threading", "GetMachineTypeAttributes", InvalidNumberOfArguments),
    ("Threading", "GetNumaNodeNumberFromHandle", NotImplementedLinux),
    ("Threading", "GetNumaNodeProcessorMask2", NotImplementedWindows),
    ("Threading", "GetProcessDefaultCpuSetMasks", NotImplementedWindows),
    ("Threading", "GetProcessDefaultCpuSets", NotImplementedLinux),
    ("Threading", "GetThreadDescription", InvalidNumberOfArguments),
    ("Threading", "GetThreadSelectedCpuSetMasks", NotImplementedWindows),
    ("Threading", "GetThreadSelectedCpuSets", NotImplementedLinux),
    ("Threading", "InitializeSListHead", CrashesWindows),
    ("Threading", "InterlockedFlushSList", CrashesWindows),
    ("Threading", "InterlockedPushEntrySList", CrashesWindows),
    ("Threading", "InterlockedPushListSListEx", CrashesWindows),
    ("Threading", "IsImmersiveProcess", NotImplementedLinux),
    ("Threading", "IsProcessCritical", NotImplementedLinux),
    ("Threading", "QueueUserAPC2", NotImplementedWindows),
    ("Threading", "ReleaseSRWLockShared", CrashesWindows),
    ("Threading", "SetProcessRestrictionExemption", NotImplementedLinux),
    ("Threading", "SetThreadpoolThreadMaximum", CrashesWindows),
    ("Threading", "SetThreadpoolThreadMinimum", CrashesWindows),
    ("Threading", "Sleep", Freeze),
    ("Threading", "SleepEx", Freeze),
    ("Threading", "SleepConditionVariableCS", Freeze),
    ("Threading", "SleepConditionVariableSRW", Freeze),
    ("Threading", "WinExec", CrashesLinux),
    ("Threading", "Wow64SetThreadDefaultGuestMachine", NotImplementedLinux),
    ("Threading", "Wow64SuspendThread", NotImplementedLinux),
    ("TpmBaseServices", "GetDeviceID", NotImplementedLinux),
    ("TpmBaseServices", "GetDeviceIDString", CrashesWindows),
    ("TpmBaseServices", "Tbsi_Create_Windows_Key", NotImplementedLinux),
    ("TpmBaseServices", "Tbsi_Get_TCG_Log_Ex", NotImplementedLinux),
    ("TpmBaseServices", "Tbsi_Revoke_Attestation", NotImplementedLinux),
    ("Urlmon", "CoInternetCombineUrl", CrashesLinux),
    ("Urlmon", "CoInternetCompareUrl", CrashesWindows),
    ("Urlmon", "CoInternetGetProtocolFlags", NotImplementedLinux),
    ("Urlmon", "CoInternetParseUrl", CrashesWindows),
    ("Urlmon", "FindMediaType", InvalidNumberOfArguments),
    ("Urlmon", "GetClassURL", InvalidNumberOfArguments),
    ("Urlmon", "GetSoftwareUpdateInfo", InvalidNumberOfArguments),
    ("Urlmon", "IEGetUserPrivateNamespaceName", NotImplementedLinux),
    ("Urlmon", "IEInstallScope", InvalidNumberOfArguments),
    ("Urlmon", "SetSoftwareUpdateAdvertisementState", NotImplementedLinux),
    ("Usb", "WinUsb_GetAdjustedFrameNumber", NotImplementedLinux),
    ("Vhd", "AddVirtualDiskParent", NotImplementedLinux),
    ("Vhd", "BreakMirrorVirtualDisk", NotImplementedLinux),
    ("Vhd", "CompleteForkVirtualDisk", NotImplementedLinux),
    ("Vhd", "EnumerateVirtualDiskMetadata", NotImplementedLinux),
    ("Vhd", "GetAllAttachedVirtualDiskPhysicalPaths", NotImplementedLinux),
    ("Vhd", "GetVirtualDiskPhysicalPath", NotImplementedLinux),
    ("Vhd", "QueryChangesVirtualDisk", CrashesWindows),
    ("WebDav", "DavCancelConnectionsToServer", NotImplementedLinux),
    ("WebDav", "DavDeleteConnection", NotImplementedLinux),
    ("WebDav", "DavFlushFile", NotImplementedLinux),
    ("WebDav", "DavGetExtendedError", NotImplementedLinux),
    ("WebDav", "DavGetHTTPFromUNCPath", CrashesLinux),
    ("WebDav", "DavGetTheLockOwnerOfTheFile", NotImplementedLinux),
    ("WebDav", "DavGetUNCFromHTTPPath", CrashesLinux),
    ("WebDav", "DavInvalidateCache", NotImplementedLinux),
    ("WebServicesOnDevices", "WSDUriDecode", NotImplementedLinux),
    ("WebServicesOnDevices", "WSDUriEncode", NotImplementedLinux),
    ("WebServicesOnDevices", "WSDXMLAddChild", CrashesWindows),
    ("WebServicesOnDevices", "WSDXMLAddSibling", CrashesWindows),
    ("WebServicesOnDevices", "WSDXMLCleanupElement", CrashesWindows),
    ("WebServicesOnDevices", "WSDXMLGetValueFromAny", CrashesWindows),
    ("WebSocket", "WebSocketAbortHandle", CrashesWindows),
    ("WebSocket", "WebSocketEndServerHandshake", CrashesWindows),
    ("WiFi", "WFDCancelOpenSession", NotImplementedLinux),
    ("WiFi", "WFDCloseHandle", NotImplementedLinux),
    ("WiFi", "WFDCloseSession", NotImplementedLinux),
    ("WiFi", "WFDOpenHandle", NotImplementedLinux),
    ("WinHttp", "WinHttpFreeQueryConnectionGroupResult", NotImplementedWindows),
    ("WinHttp", "WinHttpSetProxySettingsPerUser", NotImplementedLinux),
    ("WinInet", "AppCacheDeleteGroup", NotImplementedLinux),
    ("WinInet", "AppCacheDeleteIEGroup", NotImplementedLinux),
    ("WinInet", "AppCacheFreeIESpace", NotImplementedLinux),
    ("WinInet", "AppCacheFreeSpace", NotImplementedLinux),
    ("WinInet", "CreateUrlCacheEntryExW", NotImplementedLinux),
    ("WinInet", "DoConnectoidsExist", NotImplementedWindows),
    ("WinInet", "ExportCookieFileA", NotImplementedWindows),
    ("WinInet", "ExportCookieFileW", NotImplementedWindows),
    ("WinInet", "FindFirstUrlCacheEntryW", CrashesWindows),
    ("WinInet", "FindP3PPolicySymbol", NotImplementedWindows),
    ("WinInet", "FwpmDynamicKeywordUnsubscribe0", NotImplementedWindows),
    ("WinInet", "GetDiskInfoA", NotImplementedWindows),
    ("WinInet", "GetUrlCacheHeaderData", NotImplementedLinux),
    ("WinInet", "HttpGetServerCredentials", NotImplementedLinux),
    ("WinInet", "HttpIsHostHstsEnabled", NotImplementedLinux),
    ("WinInet", "ImportCookieFileA", NotImplementedWindows),
    ("WinInet", "ImportCookieFileW", NotImplementedWindows),
    ("WinInet", "InternalInternetGetCookie", NotImplementedWindows),
    ("WinInet", "InternetAlgIdToStringA", NotImplementedLinux),
    ("WinInet", "InternetAlgIdToStringW", NotImplementedLinux),
    ("WinInet", "InternetConvertUrlFromWireToWideChar", NotImplementedLinux),
    ("WinInet", "InternetFortezzaCommand", NotImplementedLinux),
    ("WinInet", "InternetFreeCookies", CrashesWindows),
    ("WinInet", "InternetSecurityProtocolToStringA", NotImplementedLinux),
    ("WinInet", "InternetSecurityProtocolToStringW", NotImplementedLinux),
    ("WinInet", "InternetSetDialState", NotImplementedLinux),
    ("WinInet", "InternetSetDialStateA", NotImplementedLinux),
    ("WinInet", "InternetSetDialStateW", NotImplementedLinux),
    ("WinInet", "InternetShowSecurityInfoByURL", CrashesWindows),
    ("WinInet", "InternetShowSecurityInfoByURLA", CrashesWindows),
    ("WinInet", "InternetShowSecurityInfoByURLW", CrashesWindows),
    ("WinInet", "InternetUnlockRequestFile", CrashesWindows),
    ("WinInet", "IsDomainLegalCookieDomainA", NotImplementedWindows),
    ("WinInet", "IsDomainLegalCookieDomainW", NotImplementedWindows),
    ("WinInet", "IsProfilesEnabled", NotImplementedWindows),
    ("WinInet", "SetUrlCacheHeaderData", NotImplementedLinux),
    ("WinInet", "UpdateUrlCacheContentPath", NotImplementedLinux),
    ("WinInet", "UrlCacheContainerSetEntryMaximumAge", NotImplementedLinux),
    ("WinInet", "UrlCacheCreateContainer", NotImplementedLinux),
    ("WinInet", "UrlCacheFreeGlobalSpace", NotImplementedLinux),
    ("WinInet", "UrlCacheGetGlobalCacheSize", NotImplementedLinux),
    ("WinInet", "UrlCacheReloadSettings", NotImplementedLinux),
    ("WinInet", "UrlCacheServer", NotImplementedLinux),
    ("WinRT", "CoDecodeProxy", InvalidNumberOfArguments),
    ("WinRT", "IsErrorPropagationEnabled", NotImplementedLinux),
    ("WinRT", "RoClearError", NotImplementedLinux),
    ("WinRT", "RoFailFastWithErrorContext", CrashesWindows),
    ("WinRT", "RoGetApartmentIdentifier", InvalidNumberOfArguments),
    ("WinRT", "RoGetErrorReportingFlags", InvalidNumberOfArguments),
    ("WinRT", "RoParameterizedTypeExtraGetTypeSignature", CrashesWindows),
    ("WinRT", "RoRevokeActivationFactories", NotImplementedLinux),
    ("WinRT", "RoSetErrorReportingFlags", NotImplementedLinux),
    ("WinRT", "WindowsCompareStringOrdinal", InvalidNumberOfArguments),
    ("WinRT", "WindowsConcatString", InvalidNumberOfArguments),
    ("WinRT", "WindowsCreateString", InvalidNumberOfArguments),
    ("WinRT", "WindowsDuplicateString", InvalidNumberOfArguments),
    ("WinRT", "WindowsPromoteStringBuffer", InvalidNumberOfArguments),
    ("WinRT", "WindowsReplaceString", InvalidNumberOfArguments),
    ("WinRT", "WindowsStringHasEmbeddedNull", InvalidNumberOfArguments),
    ("WinRT", "WindowsSubstring", InvalidNumberOfArguments),
    ("WinRT", "WindowsSubstringWithSpecifiedLength", InvalidNumberOfArguments),
    ("WinRT", "WindowsTrimStringEnd", InvalidNumberOfArguments),
    ("WinRT", "WindowsTrimStringStart", InvalidNumberOfArguments),
    ("WinTrust", "OpenPersonalTrustDBDialog", ShowsDialogWindows),
    ("WinTrust", "WTHelperCertCheckValidSignature", CrashesWindows),
    ("WinTrust", "WintrustSetDefaultIncludePEPageHashes", NotImplementedLinux),
    ("WindowsAndMessaging", "MrmGetPriFileContentChecksum", InvalidNumberOfArguments),
    ("WindowsConnectionManager", "OnDemandGetRoutingHint", InvalidNumberOfArguments),
    ("WindowsFilteringPlatform", "FwpmCalloutDeleteById0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmCalloutDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmCalloutUnsubscribeChanges0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmConnectionDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmConnectionUnsubscribe0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmDynamicKeywordUnsubscribe0", NotImplementedWindows),
    ("WindowsFilteringPlatform", "FwpmFilterDeleteById0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmFilterUnsubscribeChanges0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmLayerDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmNetEventDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmNetEventUnsubscribe0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmProviderContextDeleteById0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmProviderContextDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmProviderContextUnsubscribeChanges0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmProviderDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmProviderUnsubscribeChanges0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmSessionDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmSubLayerDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmSubLayerUnsubscribeChanges0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmSystemPortsUnsubscribe0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmTransactionAbort0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmTransactionBegin0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmTransactionCommit0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "FwpmvSwitchEventUnsubscribe0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IPsecDospStateDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IPsecKeyManagerUnregisterAndDelete0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IPsecSaContextDeleteById0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IPsecSaContextDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IPsecSaContextExpire0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IPsecSaContextUnsubscribe0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IPsecSaDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IkeextSaDeleteById0", NotImplementedLinux),
    ("WindowsFilteringPlatform", "IkeextSaDestroyEnumHandle0", NotImplementedLinux),
    ("WindowsProgramming", "QueryAuxiliaryCounterFrequency", InvalidNumberOfArguments),
    ("WindowsProgramming", "WldpIsDynamicCodePolicyEnabled", InvalidNumberOfArguments),
    (
        "WindowsWebServices",
        "WebAuthNIsUserVerifyingPlatformAuthenticatorAvailable",
        InvalidNumberOfArguments,
    ),
];

pub struct FileData {
    pub(crate) functions: BTreeMap<String, Vec<String>>,
}
impl FileData {
    pub fn new() -> Self {
        FileData {
            functions: Default::default(),
        }
    }
}
